@@ -4,7 +4,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -13,45 +13,39 @@
 # Run a system test.
 #
 
-SYSTEMTESTTOP="$(cd -P -- "$(dirname -- "$0")" && pwd -P)"
+SYSTEMTESTTOP=.
 . $SYSTEMTESTTOP/conf.sh
 
-if [ "`id -u`" -eq "0" ] && ! ${NAMED} -V | grep -q -F -- "enable-developer"; then
-    echofail "Refusing to run test as root. Build with --enable-developer to override." >&2
-    exit 1
-fi
-
-export SYSTEMTESTTOP
-
 stopservers=true
 baseport=5300
 
 if [ ${SYSTEMTEST_NO_CLEAN:-0} -eq 1 ]; then
-    clean=false
+	clean=false
 else
-    clean=true
+	clean=true
 fi
 
 while getopts "knp:r-:" flag; do
     case "$flag" in
-    -) case "${OPTARG}" in
+	-) case "${OPTARG}" in
                keep) stopservers=false ;;
                noclean) clean=false ;;
            esac
            ;;
-    k) stopservers=false ;;
-    n) clean=false ;;
-    p) baseport=$OPTARG ;;
+	k) stopservers=false ;;
+	n) clean=false ;;
+	p) baseport=$OPTARG ;;
+	r) runall="-r" ;;
     esac
 done
 shift `expr $OPTIND - 1`
 
 if [ $# -eq 0 ]; then
-    echofail "Usage: $0 [-k] [-n] [-p <PORT>] test-directory [test-options]" >&2;
+    echofail "Usage: $0 [-k] [-n] [-p <PORT>] [-r] test-directory [test-options]" >&2;
     exit 1
 fi
 
-systest=${1%%/}
+systest=$1
 shift
 
 if [ ! -d $systest ]; then
@@ -159,12 +153,6 @@ else
     exit 0
 fi
 
-# Clean up files left from any potential previous runs
-if test -f $systest/clean.sh
-then
-   ( cd $systest && $SHELL clean.sh "$@" )
-fi
-
 # Set up any dynamically generated test data
 if test -f $systest/setup.sh
 then
@@ -195,61 +183,22 @@ $PERL stop.pl $systest
 
 status=`expr $status + $?`
 
-get_core_dumps() {
-    find "$systest/" \( -name 'core' -or -name 'core.*' -or -name '*.core' \) ! -name '*.gz' ! -name '*.txt' | sort
-}
-
-core_dumps=$(get_core_dumps | tr '\n' ' ')
-assertion_failures=$(find "$systest/" -name named.run -print0 | xargs -0 grep "assertion failure" | wc -l)
-sanitizer_summaries=$(find "$systest/" -name 'tsan.*' | wc -l)
-if [ -n "$core_dumps" ]; then
-    echoinfo "I:$systest:Core dump(s) found: $core_dumps"
-    echofail "R:$systest:FAIL"
-    get_core_dumps | while read -r coredump; do
-        SYSTESTDIR="$systest"
-        echoinfo "D:$systest:backtrace from $coredump:"
-        echoinfo "D:$systest:--------------------------------------------------------------------------------"
-        binary=$(gdb --batch --core="$coredump" 2>/dev/null | sed -ne "s|Core was generated by \`\([^' ]*\)[' ].*|\1|p")
-        if [ ! -f "${binary}" ]; then
-            binary=$(find "${TOP}" -path "*/.libs/${binary}" -type f)
-        fi
-        "${TOP}/libtool" --mode=execute gdb \
-                                  -batch \
-                                  -ex bt \
-                                  -core="$coredump" \
-                                  -- \
-                                  "$binary" 2>/dev/null | sed -n '/^Core was generated by/,$p' | cat_d
-        echoinfo "D:$systest:--------------------------------------------------------------------------------"
-        coredump_backtrace="${coredump}-backtrace.txt"
-        echoinfo "D:$systest:full backtrace from $coredump saved in $coredump_backtrace"
-        "${TOP}/libtool" --mode=execute gdb \
-                      -batch \
-                      -command=run.gdb \
-                      -core="$coredump" \
-                      -- \
-                      "$binary" > "$coredump_backtrace" 2>&1
-        echoinfo "D:$systest:core dump $coredump archived as $coredump.gz"
-        gzip -1 "${coredump}"
-    done
-elif [ "$assertion_failures" -ne 0 ]; then
-    echoinfo "I:$systest:$assertion_failures assertion failure(s) found"
-    find "$systest/" -name 'tsan.*' -print0 | xargs -0 grep "SUMMARY: " | sort -u | cat_d
-    echofail "R:$systest:FAIL"
-elif [ "$sanitizer_summaries" -ne 0 ]; then
-    echoinfo "I:$systest:$sanitizer_summaries sanitizer report(s) found"
-    echofail "R:$systest:FAIL"
-elif [ "$status" != 0 ]; then
+if [ $status != 0 ]; then
     echofail "R:$systest:FAIL"
+    # Do not clean up - we need the evidence.
+    find . -name core -exec chmod 0644 '{}' \;
 else
     echopass "R:$systest:PASS"
-    if $clean; then
-        ( cd $systest && $SHELL clean.sh "$@" )
-        if test -d ../../../.git; then
-            git status -su --ignored $systest 2>/dev/null | \
-            sed -n -e 's|^?? \(.*\)|I:file \1 not removed|p' \
-            -e 's|^!! \(.*/named.run\)$|I:file \1 not removed|p' \
-            -e 's|^!! \(.*/named.memstats\)$|I:file \1 not removed|p'
-        fi
+    if $clean
+    then
+	$SHELL clean.sh $runall $systest "$@"
+	if test -d ../../../.git
+	then
+	    git status -su --ignored $systest 2>/dev/null | \
+	    sed -n -e 's|^?? \(.*\)|I:file \1 not removed|p' \
+	    -e 's|^!! \(.*/named.run\)$|I:file \1 not removed|p' \
+	    -e 's|^!! \(.*/named.memstats\)$|I:file \1 not removed|p'
+	fi
     fi
 fi
 
