@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -94,7 +94,7 @@ static bool besteffort = true;
 static bool display_short_form = false;
 static bool display_headers = true;
 static bool display_comments = true;
-static int display_rrcomments = 0;
+static bool display_rrcomments = true;
 static bool display_ttlunits = true;
 static bool display_ttl = true;
 static bool display_class = true;
@@ -248,7 +248,7 @@ recvresponse(isc_task_t *task, isc_event_t *event) {
 		styleflags |= DNS_STYLEFLAG_COMMENT;
 	if (display_unknown_format)
 		styleflags |= DNS_STYLEFLAG_UNKNOWNFORMAT;
-	if (display_rrcomments > 0)
+	if (display_rrcomments)
 		styleflags |= DNS_STYLEFLAG_RRCOMMENT;
 	if (display_ttlunits)
 		styleflags |= DNS_STYLEFLAG_TTL_UNITS;
@@ -266,10 +266,7 @@ recvresponse(isc_task_t *task, isc_event_t *event) {
 		styleflags |= DNS_STYLEFLAG_TTL;
 		styleflags |= DNS_STYLEFLAG_MULTILINE;
 		styleflags |= DNS_STYLEFLAG_COMMENT;
-		/* Turn on rrcomments unless explicitly disabled */
-		if (display_rrcomments >= 0) {
-			styleflags |= DNS_STYLEFLAG_RRCOMMENT;
-		}
+		styleflags |= DNS_STYLEFLAG_RRCOMMENT;
 	}
 	if (display_multiline || (!display_ttl && !display_class))
 		result = dns_master_stylecreate2(&style, styleflags,
@@ -478,9 +475,9 @@ cleanup:
 	if (style != NULL)
 		dns_master_styledestroy(&style, mctx);
 	if (query != NULL)
-		dns_message_detach(&query);
+		dns_message_destroy(&query);
 	if (response != NULL)
-		dns_message_detach(&response);
+		dns_message_destroy(&response);
 	dns_request_destroy(&reqev->request);
 	isc_event_free(&event);
 
@@ -915,6 +912,7 @@ save_opt(struct query *query, char *code, char *value) {
 
 static isc_result_t
 parse_netprefix(isc_sockaddr_t **sap, const char *value) {
+	isc_result_t result = ISC_R_SUCCESS;
 	isc_sockaddr_t *sa = NULL;
 	struct in_addr in4;
 	struct in6_addr in6;
@@ -928,7 +926,6 @@ parse_netprefix(isc_sockaddr_t **sap, const char *value) {
 
 	slash = strchr(buf, '/');
 	if (slash != NULL) {
-		isc_result_t result;
 		*slash = '\0';
 		result = isc_parse_uint32(&netmask, slash + 1, 10);
 		if (result != ISC_R_SUCCESS) {
@@ -1128,7 +1125,7 @@ plus_option(char *option, struct query *query, bool global)
 			display_authority = state;
 			display_additional = state;
 			display_comments = state;
-			display_rrcomments = state ? 1 : -1;
+			display_rrcomments = state;
 			break;
 		case 'n': /* answer */
 			FULLCHECK("answer");
@@ -1370,7 +1367,7 @@ plus_option(char *option, struct query *query, bool global)
 		case 'r':
 			FULLCHECK("rrcomments");
 			GLOBAL();
-			display_rrcomments = state ? 1 : -1;
+			display_rrcomments = state;
 			break;
 		default:
 			goto invalid_option;
@@ -1388,7 +1385,7 @@ plus_option(char *option, struct query *query, bool global)
 				display_authority = false;
 				display_additional = false;
 				display_comments = false;
-				display_rrcomments = -1;
+				display_rrcomments = false;
 			}
 			break;
 		case 'p': /* split */
@@ -1547,7 +1544,7 @@ plus_option(char *option, struct query *query, bool global)
  * #true returned if value was used
  */
 static const char *single_dash_opts = "46himv";
-static const char *dash_opts = "46bcfhiptvx";
+/*static const char *dash_opts = "46bcfhiptvx";*/
 static bool
 dash_option(const char *option, char *next, struct query *query,
 	    bool global, bool *setname)
@@ -1767,20 +1764,6 @@ preparse_args(int argc, char **argv) {
 			}
 			option = &option[1];
 		}
-		if (strlen(option) == 0U) {
-			continue;
-		}
-		/* Look for dash value option. */
-		if (strpbrk(option, dash_opts) != &option[0] ||
-		    strlen(option) > 1U) {
-			/* Error or value in option. */
-			continue;
-		}
-		/* Dash value is next argument so we need to skip it. */
-		rc--, rv++;
-		/* Handle missing argument */
-		if (rc == 0)
-			break;
 	}
 }
 
@@ -1972,12 +1955,11 @@ main(int argc, char *argv[]) {
 
 	ectx = NULL;
 	RUNCHECK(isc_entropy_create(mctx, &ectx));
+	RUNCHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_GOODONLY));
 	RUNCHECK(isc_hash_create(mctx, ectx, DNS_NAME_MAXWIRE));
 	RUNCHECK(isc_entropy_getdata(ectx, cookie_secret,
 				     sizeof(cookie_secret), NULL, 0));
 
-	RUNCHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_GOODONLY));
-
 	ISC_LIST_INIT(queries);
 	parse_args(false, argc, argv);
 	if (server == NULL)
