@@ -18,8 +18,6 @@
 #include <isc/buffer.h>
 #include <isc/mem.h>
 #include <isc/mutex.h>
-#include <isc/portset.h>
-#include <isc/refcount.h>
 #include <isc/safe.h>
 #include <isc/sockaddr.h>
 #include <isc/socket.h>
@@ -95,9 +93,8 @@ struct dns_client {
 	unsigned int			find_timeout;
 	unsigned int			find_udpretries;
 
-	isc_refcount_t			references;
-
 	/* Locked */
+	unsigned int			references;
 	dns_viewlist_t			viewlist;
 	ISC_LIST(struct resctx)		resctxs;
 	ISC_LIST(struct reqctx)		reqctxs;
@@ -117,8 +114,6 @@ struct dns_client {
 
 #define DNS_CLIENTATTR_OWNCTX			0x01
 
-#define DNS_CLIENTVIEW_NAME			"dnsclient"
-
 /*%
  * Internal state for a single name resolution procedure
  */
@@ -127,10 +122,10 @@ typedef struct resctx {
 	unsigned int		magic;
 	isc_mutex_t		lock;
 	dns_client_t		*client;
-	bool			want_dnssec;
-	bool			want_validation;
-	bool			want_cdflag;
-	bool			want_tcp;
+	bool		want_dnssec;
+	bool		want_validation;
+	bool		want_cdflag;
+	bool		want_tcp;
 
 	/* Locked */
 	ISC_LINK(struct resctx)	link;
@@ -143,7 +138,7 @@ typedef struct resctx {
 	dns_namelist_t		namelist;
 	isc_result_t		result;
 	dns_clientresevent_t	*event;
-	bool			canceled;
+	bool		canceled;
 	dns_rdataset_t		*rdataset;
 	dns_rdataset_t		*sigrdataset;
 } resctx_t;
@@ -162,7 +157,7 @@ typedef struct resarg {
 	isc_result_t		vresult;
 	dns_namelist_t		*namelist;
 	dns_clientrestrans_t	*trans;
-	bool			canceled;
+	bool		canceled;
 } resarg_t;
 
 /*%
@@ -177,7 +172,7 @@ typedef struct reqctx {
 
 	/* Locked */
 	ISC_LINK(struct reqctx)	link;
-	bool			canceled;
+	bool		canceled;
 	dns_tsigkey_t		*tsigkey;
 	dns_request_t		*request;
 	dns_clientreqevent_t	*event;
@@ -195,7 +190,7 @@ typedef struct reqarg {
 	/* Locked */
 	isc_result_t		result;
 	dns_clientreqtrans_t	*trans;
-	bool			canceled;
+	bool		canceled;
 } reqarg_t;
 
 /*%
@@ -210,7 +205,7 @@ typedef struct updatearg {
 	/* Locked */
 	isc_result_t		result;
 	dns_clientupdatetrans_t	*trans;
-	bool			canceled;
+	bool		canceled;
 } updatearg_t;
 
 /*%
@@ -221,14 +216,14 @@ typedef struct updatectx {
 	unsigned int			magic;
 	isc_mutex_t			lock;
 	dns_client_t			*client;
-	bool				want_tcp;
+	bool			want_tcp;
 
 	/* Locked */
 	dns_request_t			*updatereq;
 	dns_request_t			*soareq;
 	dns_clientrestrans_t		*restrans;
 	dns_clientrestrans_t		*restrans2;
-	bool				canceled;
+	bool			canceled;
 
 	/* Task Locked */
 	ISC_LINK(struct updatectx) 	link;
@@ -255,53 +250,11 @@ static isc_result_t request_soa(updatectx_t *uctx);
 static void client_resfind(resctx_t *rctx, dns_fetchevent_t *event);
 static isc_result_t send_update(updatectx_t *uctx);
 
-/*
- * Try honoring the operating system's preferred ephemeral port range.
- */
-static isc_result_t
-setsourceports(isc_mem_t *mctx, dns_dispatchmgr_t *manager) {
-	isc_portset_t *v4portset = NULL, *v6portset = NULL;
-	in_port_t udpport_low, udpport_high;
-	isc_result_t result;
-
-	result = isc_portset_create(mctx, &v4portset);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup;
-	}
-	result = isc_net_getudpportrange(AF_INET, &udpport_low, &udpport_high);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup;
-	}
-	isc_portset_addrange(v4portset, udpport_low, udpport_high);
-
-	result = isc_portset_create(mctx, &v6portset);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup;
-	}
-	result = isc_net_getudpportrange(AF_INET6, &udpport_low, &udpport_high);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup;
-	}
-	isc_portset_addrange(v6portset, udpport_low, udpport_high);
-
-	result = dns_dispatchmgr_setavailports(manager, v4portset, v6portset);
-
- cleanup:
-	if (v4portset != NULL) {
-		isc_portset_destroy(mctx, &v4portset);
-	}
-	if (v6portset != NULL) {
-		isc_portset_destroy(mctx, &v6portset);
-	}
-
-	return (result);
-}
-
 static isc_result_t
 getudpdispatch(int family, dns_dispatchmgr_t *dispatchmgr,
 	       isc_socketmgr_t *socketmgr, isc_taskmgr_t *taskmgr,
 	       bool is_shared, dns_dispatch_t **dispp,
-	       isc_sockaddr_t *localaddr)
+	       const isc_sockaddr_t *localaddr)
 {
 	unsigned int attrs, attrmask;
 	dns_dispatch_t *disp;
@@ -320,7 +273,6 @@ getudpdispatch(int family, dns_dispatchmgr_t *dispatchmgr,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 	attrmask = 0;
 	attrmask |= DNS_DISPATCHATTR_UDP;
@@ -329,8 +281,8 @@ getudpdispatch(int family, dns_dispatchmgr_t *dispatchmgr,
 	attrmask |= DNS_DISPATCHATTR_IPV6;
 
 	if (localaddr == NULL) {
+		isc_sockaddr_anyofpf(&anyaddr, family);
 		localaddr = &anyaddr;
-		isc_sockaddr_anyofpf(localaddr, family);
 	}
 
 	buffersize = 4096;
@@ -488,8 +440,8 @@ isc_result_t
 dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 		    isc_taskmgr_t *taskmgr, isc_socketmgr_t *socketmgr,
 		    isc_timermgr_t *timermgr, unsigned int options,
-		    dns_client_t **clientp, isc_sockaddr_t *localaddr4,
-		    isc_sockaddr_t *localaddr6)
+		    dns_client_t **clientp, const isc_sockaddr_t *localaddr4,
+		    const isc_sockaddr_t *localaddr6)
 {
 	dns_client_t *client;
 	isc_result_t result;
@@ -510,7 +462,8 @@ dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 
 	result = isc_mutex_init(&client->lock);
 	if (result != ISC_R_SUCCESS) {
-		goto cleanup_client;
+		isc_mem_put(mctx, client, sizeof(*client));
+		return (result);
 	}
 
 	client->actx = actx;
@@ -520,16 +473,13 @@ dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 
 	client->task = NULL;
 	result = isc_task_create(client->taskmgr, 0, &client->task);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_lock;
-	}
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 
 	result = dns_dispatchmgr_create(mctx, NULL, &dispatchmgr);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_task;
-	}
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 	client->dispatchmgr = dispatchmgr;
-	(void)setsourceports(mctx, dispatchmgr);
 
 	/*
 	 * If only one address family is specified, use it.
@@ -540,9 +490,8 @@ dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 		result = getudpdispatch(AF_INET, dispatchmgr, socketmgr,
 					taskmgr, true,
 					&dispatchv4, localaddr4);
-		if (result == ISC_R_SUCCESS) {
+		if (result == ISC_R_SUCCESS)
 			client->dispatchv4 = dispatchv4;
-		}
 	}
 
 	client->dispatchv6 = NULL;
@@ -550,30 +499,22 @@ dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 		result = getudpdispatch(AF_INET6, dispatchmgr, socketmgr,
 					taskmgr, true,
 					&dispatchv6, localaddr6);
-		if (result == ISC_R_SUCCESS) {
+		if (result == ISC_R_SUCCESS)
 			client->dispatchv6 = dispatchv6;
-		}
 	}
 
 	/* We need at least one of the dispatchers */
 	if (dispatchv4 == NULL && dispatchv6 == NULL) {
 		INSIST(result != ISC_R_SUCCESS);
-		goto cleanup_dispatchmgr;
-	}
-
-	result = isc_refcount_init(&client->references, 1);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_dispatches;
+		goto cleanup;
 	}
 
 	/* Create the default view for class IN */
 	result = createview(mctx, dns_rdataclass_in, options, taskmgr,
 			    RESOLVER_NTASKS, socketmgr, timermgr,
 			    dispatchmgr, dispatchv4, dispatchv6, &view);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_references;
-	}
-
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 	ISC_LIST_INIT(client->viewlist);
 	ISC_LIST_APPEND(client->viewlist, view, link);
 
@@ -593,38 +534,32 @@ dns_client_createx2(isc_mem_t *mctx, isc_appctx_t *actx,
 	client->find_udpretries = DEF_FIND_UDPRETRIES;
 	client->attributes = 0;
 
+	client->references = 1;
 	client->magic = DNS_CLIENT_MAGIC;
 
 	*clientp = client;
 
 	return (ISC_R_SUCCESS);
 
- cleanup_references:
-	isc_refcount_decrement(&client->references, NULL);
-	isc_refcount_destroy(&client->references);
- cleanup_dispatches:
+ cleanup:
 	if (dispatchv4 != NULL)
 		dns_dispatch_detach(&dispatchv4);
 	if (dispatchv6 != NULL)
 		dns_dispatch_detach(&dispatchv6);
- cleanup_dispatchmgr:
-	dns_dispatchmgr_destroy(&dispatchmgr);
- cleanup_task:
-	isc_task_detach(&client->task);
- cleanup_lock:
-	DESTROYLOCK(&client->lock);
- cleanup_client:
+	if (dispatchmgr != NULL)
+		dns_dispatchmgr_destroy(&dispatchmgr);
+	if (client->task != NULL)
+		isc_task_detach(&client->task);
 	isc_mem_put(mctx, client, sizeof(*client));
 
 	return (result);
 }
 
 static void
-destroyclient(dns_client_t *client) {
+destroyclient(dns_client_t **clientp) {
+	dns_client_t *client = *clientp;
 	dns_view_t *view;
 
-	isc_refcount_destroy(&client->references);
-
 	while ((view = ISC_LIST_HEAD(client->viewlist)) != NULL) {
 		ISC_LIST_UNLINK(client->viewlist, view, link);
 		dns_view_detach(&view);
@@ -656,27 +591,37 @@ destroyclient(dns_client_t *client) {
 	client->magic = 0;
 
 	isc_mem_putanddetach(&client->mctx, client, sizeof(*client));
+
+	*clientp = NULL;
 }
 
 void
 dns_client_destroy(dns_client_t **clientp) {
 	dns_client_t *client;
-	uint32_t references;
+	bool destroyok = false;
 
 	REQUIRE(clientp != NULL);
 	client = *clientp;
-	*clientp = NULL;
 	REQUIRE(DNS_CLIENT_VALID(client));
 
-	isc_refcount_decrement(&client->references, &references);
-	if (references == 0U) {
-		destroyclient(client);
+	LOCK(&client->lock);
+	client->references--;
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs)) {
+		destroyok = true;
 	}
+	UNLOCK(&client->lock);
+
+	if (destroyok)
+		destroyclient(&client);
+
+	*clientp = NULL;
 }
 
 isc_result_t
 dns_client_setservers(dns_client_t *client, dns_rdataclass_t rdclass,
-		      dns_name_t *name_space, isc_sockaddrlist_t *addrs)
+		      const dns_name_t *name_space, isc_sockaddrlist_t *addrs)
 {
 	isc_result_t result;
 	dns_view_t *view = NULL;
@@ -706,7 +651,7 @@ dns_client_setservers(dns_client_t *client, dns_rdataclass_t rdclass,
 
 isc_result_t
 dns_client_clearservers(dns_client_t *client, dns_rdataclass_t rdclass,
-			dns_name_t *name_space)
+			const dns_name_t *name_space)
 {
 	isc_result_t result;
 	dns_view_t *view = NULL;
@@ -1119,12 +1064,6 @@ client_resfind(resctx_t *rctx, dns_fetchevent_t *event) {
 					}
 				}
 			}
-			if (rctx->rdataset != NULL) {
-				putrdataset(mctx, &rctx->rdataset);
-			}
-			if (rctx->sigrdataset != NULL) {
-				putrdataset(mctx, &rctx->sigrdataset);
-			}
 			if (n == 0) {
 				/*
 				 * We didn't match any rdatasets (which means
@@ -1287,7 +1226,7 @@ resolve_done(isc_task_t *task, isc_event_t *event) {
 }
 
 isc_result_t
-dns_client_resolve(dns_client_t *client, dns_name_t *name,
+dns_client_resolve(dns_client_t *client, const dns_name_t *name,
 		   dns_rdataclass_t rdclass, dns_rdatatype_t type,
 		   unsigned int options, dns_namelist_t *namelist)
 {
@@ -1373,7 +1312,7 @@ dns_client_resolve(dns_client_t *client, dns_name_t *name,
 }
 
 isc_result_t
-dns_client_startresolve(dns_client_t *client, dns_name_t *name,
+dns_client_startresolve(dns_client_t *client, const dns_name_t *name,
 			dns_rdataclass_t rdclass, dns_rdatatype_t type,
 			unsigned int options, isc_task_t *task,
 			isc_taskaction_t action, void *arg,
@@ -1401,10 +1340,10 @@ dns_client_startresolve(dns_client_t *client, dns_name_t *name,
 	mctx = client->mctx;
 	rdataset = NULL;
 	sigrdataset = NULL;
-	want_dnssec = ((options & DNS_CLIENTRESOPT_NODNSSEC) == 0);
-	want_validation = ((options & DNS_CLIENTRESOPT_NOVALIDATE) == 0);
-	want_cdflag = ((options & DNS_CLIENTRESOPT_NOCDFLAG) == 0);
-	want_tcp = ((options & DNS_CLIENTRESOPT_TCP) != 0);
+	want_dnssec = !(options & DNS_CLIENTRESOPT_NODNSSEC);
+	want_validation = !(options & DNS_CLIENTRESOPT_NOVALIDATE);
+	want_cdflag = !(options & DNS_CLIENTRESOPT_NOCDFLAG);
+	want_tcp = (options & DNS_CLIENTRESOPT_TCP);
 
 	/*
 	 * Prepare some intermediate resources
@@ -1467,7 +1406,6 @@ dns_client_startresolve(dns_client_t *client, dns_name_t *name,
 	rctx->event = event;
 
 	rctx->magic = RCTX_MAGIC;
-	isc_refcount_increment(&client->references, NULL);
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->resctxs, rctx, link);
@@ -1538,10 +1476,10 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 	resctx_t *rctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 
 	REQUIRE(transp != NULL);
 	rctx = (resctx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(RCTX_VALID(rctx));
 	REQUIRE(rctx->fetch == NULL);
 	REQUIRE(rctx->event == NULL);
@@ -1563,6 +1501,11 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(rctx, link));
 	ISC_LIST_UNLINK(client->resctxs, rctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs))
+		need_destroyclient = true;
+
 	UNLOCK(&client->lock);
 
 	INSIST(ISC_LIST_EMPTY(rctx->namelist));
@@ -1572,13 +1515,15 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 
 	isc_mem_put(mctx, rctx, sizeof(*rctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
 
+	*transp = NULL;
 }
 
 isc_result_t
 dns_client_addtrustedkey(dns_client_t *client, dns_rdataclass_t rdclass,
-			 dns_name_t *keyname, isc_buffer_t *keydatabuf)
+			 const dns_name_t *keyname, isc_buffer_t *keydatabuf)
 {
 	isc_result_t result;
 	dns_view_t *view = NULL;
@@ -1603,7 +1548,7 @@ dns_client_addtrustedkey(dns_client_t *client, dns_rdataclass_t rdclass,
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 
-	result = dns_keytable_add(secroots, false, &dstkey);
+	result = dns_keytable_add2(secroots, false, false, &dstkey);
 
  cleanup:
 	if (dstkey != NULL)
@@ -1690,7 +1635,7 @@ localrequest_done(isc_task_t *task, isc_event_t *event) {
 
 isc_result_t
 dns_client_request(dns_client_t *client, dns_message_t *qmessage,
-		   dns_message_t *rmessage, isc_sockaddr_t *server,
+		   dns_message_t *rmessage, const isc_sockaddr_t *server,
 		   unsigned int options, unsigned int parseoptions,
 		   dns_tsec_t *tsec, unsigned int timeout,
 		   unsigned int udptimeout, unsigned int udpretries)
@@ -1772,7 +1717,7 @@ dns_client_request(dns_client_t *client, dns_message_t *qmessage,
 
 isc_result_t
 dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
-			dns_message_t *rmessage, isc_sockaddr_t *server,
+			dns_message_t *rmessage, const isc_sockaddr_t *server,
 			unsigned int options, unsigned int parseoptions,
 			dns_tsec_t *tsec, unsigned int timeout,
 			unsigned int udptimeout, unsigned int udpretries,
@@ -1847,7 +1792,6 @@ dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->reqctxs, ctx, link);
-	isc_refcount_increment(&client->references, NULL);
 	UNLOCK(&client->lock);
 
 	ctx->request = NULL;
@@ -1862,8 +1806,6 @@ dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
 		return (ISC_R_SUCCESS);
 	}
 
-	isc_refcount_decrement(&client->references, NULL);
-
  cleanup:
 	if (ctx != NULL) {
 		LOCK(&client->lock);
@@ -1904,10 +1846,10 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 	reqctx_t *ctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 
 	REQUIRE(transp != NULL);
 	ctx = (reqctx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(REQCTX_VALID(ctx));
 	client = ctx->client;
 	REQUIRE(DNS_CLIENT_VALID(client));
@@ -1922,6 +1864,12 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(ctx, link));
 	ISC_LIST_UNLINK(client->reqctxs, ctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs)) {
+		need_destroyclient = true;
+	}
+
 	UNLOCK(&client->lock);
 
 	DESTROYLOCK(&ctx->lock);
@@ -1929,7 +1877,10 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 
 	isc_mem_put(mctx, ctx, sizeof(*ctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
+
+	*transp = NULL;
 }
 
 /*%
@@ -2247,7 +2198,9 @@ resolveaddr_done(isc_task_t *task, isc_event_t *event) {
 }
 
 static isc_result_t
-process_soa(updatectx_t *uctx, dns_rdataset_t *soaset, dns_name_t *soaname) {
+process_soa(updatectx_t *uctx, dns_rdataset_t *soaset,
+	    const dns_name_t *soaname)
+{
 	isc_result_t result;
 	dns_rdata_t soarr = DNS_RDATA_INIT;
 	dns_rdata_soa_t soa;
@@ -2626,7 +2579,7 @@ resolvesoa_done(isc_task_t *task, isc_event_t *event) {
 }
 
 static isc_result_t
-copy_name(isc_mem_t *mctx, dns_message_t *msg, dns_name_t *name,
+copy_name(isc_mem_t *mctx, dns_message_t *msg, const dns_name_t *name,
 	  dns_name_t **newnamep)
 {
 	isc_result_t result;
@@ -2742,7 +2695,7 @@ internal_update_callback(isc_task_t *task, isc_event_t *event) {
 
 isc_result_t
 dns_client_update(dns_client_t *client, dns_rdataclass_t rdclass,
-		  dns_name_t *zonename, dns_namelist_t *prerequisites,
+		  const dns_name_t *zonename, dns_namelist_t *prerequisites,
 		  dns_namelist_t *updates, isc_sockaddrlist_t *servers,
 		  dns_tsec_t *tsec, unsigned int options)
 {
@@ -2865,7 +2818,8 @@ fail:
 
 isc_result_t
 dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
-		       dns_name_t *zonename, dns_namelist_t *prerequisites,
+		       const dns_name_t *zonename,
+		       dns_namelist_t *prerequisites,
 		       dns_namelist_t *updates, isc_sockaddrlist_t *servers,
 		       dns_tsec_t *tsec, unsigned int options,
 		       isc_task_t *task, isc_taskaction_t action, void *arg,
@@ -2901,7 +2855,7 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
-	want_tcp = ((options & DNS_CLIENTUPDOPT_TCP) != 0);
+	want_tcp = (options & DNS_CLIENTUPDOPT_TCP);
 
 	/*
 	 * Create a context and prepare some resources.
@@ -3019,7 +2973,6 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->updatectxs, uctx, link);
-	isc_refcount_increment(&client->references, NULL);
 	UNLOCK(&client->lock);
 
 	*transp = (dns_clientupdatetrans_t *)uctx;
@@ -3038,8 +2991,6 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 	}
 	if (result == ISC_R_SUCCESS)
 		return (result);
-
-	isc_refcount_decrement(&client->references, NULL);
 	*transp = NULL;
 
  fail:
@@ -3097,11 +3048,11 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 	updatectx_t *uctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 	isc_sockaddr_t *sa;
 
 	REQUIRE(transp != NULL);
 	uctx = (updatectx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(UCTX_VALID(uctx));
 	client = uctx->client;
 	REQUIRE(DNS_CLIENT_VALID(client));
@@ -3122,6 +3073,11 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(uctx, link));
 	ISC_LIST_UNLINK(client->updatectxs, uctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs))
+		need_destroyclient = true;
+
 	UNLOCK(&client->lock);
 
 	DESTROYLOCK(&uctx->lock);
@@ -3129,7 +3085,10 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 
 	isc_mem_put(mctx, uctx, sizeof(*uctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
+
+	*transp = NULL;
 }
 
 isc_mem_t *
@@ -3150,7 +3109,7 @@ typedef struct {
 } dns_client_updaterec_t;
 
 isc_result_t
-dns_client_updaterec(dns_client_updateop_t op, dns_name_t *owner,
+dns_client_updaterec(dns_client_updateop_t op, const dns_name_t *owner,
 		     dns_rdatatype_t type, dns_rdata_t *source,
 		     dns_ttl_t ttl, dns_name_t *target,
 		     dns_rdataset_t *rdataset, dns_rdatalist_t *rdatalist,
@@ -3225,7 +3184,6 @@ dns_client_updaterec(dns_client_updateop_t op, dns_name_t *owner,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 
 	rdatalist->type = rdata->type;
