@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -260,6 +260,27 @@ dns_cache_getcachesize(dns_cache_t *cache);
  * Get the maximum cache size.
  */
 
+void
+dns_cache_setservestalettl(dns_cache_t *cache, dns_ttl_t ttl);
+/*%<
+ * Sets the maximum length of time that cached answers may be retained
+ * past their normal TTL.  Default value for the library is 0, disabling
+ * the use of stale data.
+ *
+ * Requires:
+ *\li	'cache' to be valid.
+ */
+
+dns_ttl_t
+dns_cache_getservestalettl(dns_cache_t *cache);
+/*%<
+ * Gets the maximum length of time that cached answers may be kept past
+ * normal expiry.
+ *
+ * Requires:
+ *\li	'cache' to be valid.
+ */
+
 isc_result_t
 dns_cache_flush(dns_cache_t *cache);
 /*%<
@@ -271,7 +292,7 @@ dns_cache_flush(dns_cache_t *cache);
  */
 
 isc_result_t
-dns_cache_flushnode(dns_cache_t *cache, dns_name_t *name,
+dns_cache_flushnode(dns_cache_t *cache, const dns_name_t *name,
 		    bool tree);
 /*
  * Flush a given name from the cache.  If 'tree' is true, then
@@ -288,7 +309,7 @@ dns_cache_flushnode(dns_cache_t *cache, dns_name_t *name,
  */
 
 isc_result_t
-dns_cache_flushname(dns_cache_t *cache, dns_name_t *name);
+dns_cache_flushname(dns_cache_t *cache, const dns_name_t *name);
 /*
  * Flush a given name from the cache.  Equivalent to
  * dns_cache_flushpartial(cache, name, false).
