@@ -1,26 +1,20 @@
 /*
- * Copyright (C) 2004, 2005, 2007, 2015  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 2002  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: order.c,v 1.10 2007/06/19 23:47:16 tbox Exp $ */
-
 /*! \file */
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/magic.h>
 #include <isc/mem.h>
 #include <isc/types.h>
@@ -80,7 +74,7 @@ dns_order_create(isc_mem_t *mctx, dns_order_t **orderp) {
 }
 
 isc_result_t
-dns_order_add(dns_order_t *order, dns_name_t *name,
+dns_order_add(dns_order_t *order, const dns_name_t *name,
 	      dns_rdatatype_t rdtype, dns_rdataclass_t rdclass,
 	      unsigned int mode)
 {
@@ -89,7 +83,7 @@ dns_order_add(dns_order_t *order, dns_name_t *name,
 	REQUIRE(DNS_ORDER_VALID(order));
 	REQUIRE(mode == DNS_RDATASETATTR_RANDOMIZE ||
 		mode == DNS_RDATASETATTR_FIXEDORDER ||
-		mode == 0 /* DNS_RDATASETATTR_CYCLIC */ );
+		mode == DNS_RDATASETATTR_CYCLIC);
 
 	ent = isc_mem_get(order->mctx, sizeof(*ent));
 	if (ent == NULL)
@@ -106,8 +100,8 @@ dns_order_add(dns_order_t *order, dns_name_t *name,
 	return (ISC_R_SUCCESS);
 }
 
-static inline isc_boolean_t
-match(dns_name_t *name1, dns_name_t *name2) {
+static inline bool
+match(const dns_name_t *name1, const dns_name_t *name2) {
 
 	if (dns_name_iswildcard(name2))
 		return(dns_name_matcheswildcard(name1, name2));
@@ -115,7 +109,7 @@ match(dns_name_t *name1, dns_name_t *name2) {
 }
 
 unsigned int
-dns_order_find(dns_order_t *order, dns_name_t *name,
+dns_order_find(dns_order_t *order, const dns_name_t *name,
 	       dns_rdatatype_t rdtype, dns_rdataclass_t rdclass)
 {
 	dns_order_ent_t *ent;
@@ -132,7 +126,7 @@ dns_order_find(dns_order_t *order, dns_name_t *name,
 		if (match(name, dns_fixedname_name(&ent->name)))
 			return (ent->mode);
 	}
-	return (DNS_RDATASETATTR_RANDOMIZE);
+	return (DNS_RDATASETATTR_NONE);
 }
 
 void
