@@ -135,7 +135,9 @@
 	{ DNS_KEYALG_RSASHA512, "RSASHA512", 0 }, \
 	{ DNS_KEYALG_ECCGOST, "ECCGOST", 0 }, \
 	{ DNS_KEYALG_ECDSA256, "ECDSAP256SHA256", 0 }, \
+	{ DNS_KEYALG_ECDSA256, "ECDSA256", 0 }, \
 	{ DNS_KEYALG_ECDSA384, "ECDSAP384SHA384", 0 }, \
+	{ DNS_KEYALG_ECDSA384, "ECDSA384", 0 }, \
 	{ DNS_KEYALG_ED25519, "ED25519", 0 }, \
 	{ DNS_KEYALG_ED448, "ED448", 0 }, \
 	{ DNS_KEYALG_INDIRECT, "INDIRECT", 0 }, \
@@ -244,36 +246,28 @@ maybe_numeric(unsigned int *valuep, isc_textregion_t *source,
 	isc_result_t result;
 	uint32_t n;
 	char buffer[NUMBERSIZE];
-	int v;
 
 	if (! isdigit(source->base[0] & 0xff) ||
 	    source->length > NUMBERSIZE - 1)
-	{
 		return (ISC_R_BADNUMBER);
-	}
 
 	/*
 	 * We have a potential number.	Try to parse it with
 	 * isc_parse_uint32().	isc_parse_uint32() requires
 	 * null termination, so we must make a copy.
 	 */
-	v = snprintf(buffer, sizeof(buffer), "%.*s",
-		     (int)source->length, source->base);
-	if (v < 0 || (unsigned)v != source->length) {
-		return (ISC_R_BADNUMBER);
-	}
+	snprintf(buffer, sizeof(buffer), "%.*s",
+		 (int)source->length, source->base);
+
 	INSIST(buffer[source->length] == '\0');
 
 	result = isc_parse_uint32(&n, buffer, 10);
-	if (result == ISC_R_BADNUMBER && hex_allowed) {
+	if (result == ISC_R_BADNUMBER && hex_allowed)
 		result = isc_parse_uint32(&n, buffer, 16);
-	}
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
-	if (n > max) {
+	if (n > max)
 		return (ISC_R_RANGE);
-	}
 	*valuep = n;
 	return (ISC_R_SUCCESS);
 }
@@ -381,10 +375,8 @@ dns_secalg_format(dns_secalg_t alg, char *cp, unsigned int size) {
 	result = dns_secalg_totext(alg, &b);
 	isc_buffer_usedregion(&b, &r);
 	r.base[r.length] = 0;
-	if (result != ISC_R_SUCCESS) {
-		/* cppcheck-suppress unreadVariable */
+	if (result != ISC_R_SUCCESS)
 		r.base[0] = 0;
-	}
 }
 
 isc_result_t
@@ -413,10 +405,7 @@ dns_keyflags_fromtext(dns_keyflags_t *flagsp, isc_textregion_t *source)
 {
 	isc_result_t result;
 	char *text, *end;
-	unsigned int value = 0;
-#ifdef notyet
-	unsigned int mask = 0;
-#endif
+	unsigned int value, mask;
 
 	result = maybe_numeric(&value, source, 0xffff, true);
 	if (result == ISC_R_SUCCESS) {
@@ -428,6 +417,7 @@ dns_keyflags_fromtext(dns_keyflags_t *flagsp, isc_textregion_t *source)
 
 	text = source->base;
 	end = source->base + source->length;
+	value = mask = 0;
 
 	while (text < end) {
 		struct keyflag *p;
@@ -447,8 +437,8 @@ dns_keyflags_fromtext(dns_keyflags_t *flagsp, isc_textregion_t *source)
 #ifdef notyet
 		if ((mask & p->mask) != 0)
 			warn("overlapping key flags");
-		mask |= p->mask;
 #endif
+		mask |= p->mask;
 		text += len;
 		if (delim != NULL)
 			text++; /* Skip "|" */
@@ -481,10 +471,8 @@ dns_dsdigest_format(dns_dsdigest_t typ, char *cp, unsigned int size) {
 	result = dns_dsdigest_totext(typ, &b);
 	isc_buffer_usedregion(&b, &r);
 	r.base[r.length] = 0;
-	if (result != ISC_R_SUCCESS) {
-		/* cppcheck-suppress unreadVariable */
+	if (result != ISC_R_SUCCESS)
 		r.base[0] = 0;
-	}
 }
 
 /*
