@@ -118,15 +118,13 @@ compare_md(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_md(ARGS_FROMSTRUCT) {
-	dns_rdata_md_t *md;
+	dns_rdata_md_t *md = source;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_md);
-	REQUIRE(((dns_rdata_md_t *)source) != NULL);
-	REQUIRE(((dns_rdata_md_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_md_t *)source)->common.rdclass == rdclass);
-
-	md = source;
+	REQUIRE(source != NULL);
+	REQUIRE(md->common.rdtype == type);
+	REQUIRE(md->common.rdclass == rdclass);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -137,16 +135,14 @@ fromstruct_md(ARGS_FROMSTRUCT) {
 
 static inline isc_result_t
 tostruct_md(ARGS_TOSTRUCT) {
-	dns_rdata_md_t *md;
+	dns_rdata_md_t *md = target;
 	isc_region_t r;
 	dns_name_t name;
 
-	REQUIRE(((dns_rdata_md_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_md);
+	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
-	md = target;
-
 	md->common.rdclass = rdata->rdclass;
 	md->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&md->common, link);
@@ -162,12 +158,10 @@ tostruct_md(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_md(ARGS_FREESTRUCT) {
-	dns_rdata_md_t *md;
+	dns_rdata_md_t *md = source;
 
-	REQUIRE(((dns_rdata_md_t *)source) != NULL);
-	REQUIRE(((dns_rdata_md_t *)source)->common.rdtype == dns_rdatatype_md);
-
-	md = source;
+	REQUIRE(source != NULL);
+	REQUIRE(md->common.rdtype == dns_rdatatype_md);
 
 	if (md->mctx == NULL)
 		return;
