@@ -15,6 +15,8 @@
 
 #include <atf-c.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
@@ -54,11 +56,11 @@ isc_task_t *maintask = NULL;
 isc_timermgr_t *timermgr = NULL;
 isc_socketmgr_t *socketmgr = NULL;
 dns_zonemgr_t *zonemgr = NULL;
-isc_boolean_t app_running = ISC_FALSE;
+bool app_running = false;
 int ncpus;
-isc_boolean_t debug_mem_record = ISC_TRUE;
+bool debug_mem_record = true;
 
-static isc_boolean_t hash_active = ISC_FALSE, dst_active = ISC_FALSE;
+static bool hash_active = false, dst_active = false;
 
 /*
  * Logging categories: this needs to match the list in bin/named/log.c.
@@ -110,7 +112,7 @@ create_managers(void) {
 }
 
 isc_result_t
-dns_test_begin(FILE *logfile, isc_boolean_t start_managers) {
+dns_test_begin(FILE *logfile, bool start_managers) {
 	isc_result_t result;
 
 	if (start_managers)
@@ -121,10 +123,10 @@ dns_test_begin(FILE *logfile, isc_boolean_t start_managers) {
 	CHECK(isc_entropy_create(mctx, &ectx));
 
 	CHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_BLOCKING));
-	dst_active = ISC_TRUE;
+	dst_active = true;
 
 	CHECK(isc_hash_create(mctx, ectx, DNS_NAME_MAXWIRE));
-	hash_active = ISC_TRUE;
+	hash_active = true;
 
 	if (logfile != NULL) {
 		isc_logdestination_t destination;
@@ -171,11 +173,11 @@ void
 dns_test_end(void) {
 	if (hash_active) {
 		isc_hash_destroy();
-		hash_active = ISC_FALSE;
+		hash_active = false;
 	}
 	if (dst_active) {
 		dst_lib_destroy();
-		dst_active = ISC_FALSE;
+		dst_active = false;
 	}
 	if (ectx != NULL)
 		isc_entropy_detach(&ectx);
@@ -210,7 +212,7 @@ dns_test_makeview(const char *name, dns_view_t **viewp) {
 
 isc_result_t
 dns_test_makezone(const char *name, dns_zone_t **zonep, dns_view_t *view,
-		  isc_boolean_t createview)
+		  bool createview)
 {
 	dns_fixedname_t fixed_origin;
 	dns_zone_t *zone = NULL;
@@ -314,7 +316,7 @@ dns_test_closezonemgr(void) {
  * Sleep for 'usec' microseconds.
  */
 void
-dns_test_nap(isc_uint32_t usec) {
+dns_test_nap(uint32_t usec) {
 #ifdef HAVE_NANOSLEEP
 	struct timespec ts;
 
