@@ -21,7 +21,6 @@
 #include <isc/netaddr.h>
 #include <isc/platform.h>
 #include <isc/print.h>
-#include <isc/random.h>
 #include <isc/serial.h>
 #include <isc/stats.h>
 #include <isc/stdtime.h>
@@ -1106,13 +1105,10 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	for (i = 0; i < nkeys; i++) {
 		bool both = false;
 
-		/* Don't add signatures for offline or inactive keys */
-		if (!dst_key_isprivate(keys[i])) {
+		if (!dst_key_isprivate(keys[i]))
 			continue;
-		}
-		if (dst_key_inactive(keys[i])) {
+		if (dst_key_inactive(keys[i]))	/* Should be redundant. */
 			continue;
-		}
 
 		if (check_ksk && !REVOKE(keys[i])) {
 			bool have_ksk, have_nonksk;
@@ -1124,49 +1120,40 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				have_nonksk = true;
 			}
 			for (j = 0; j < nkeys; j++) {
-				if (j == i || ALG(keys[i]) != ALG(keys[j])) {
+				if (j == i || ALG(keys[i]) != ALG(keys[j]))
 					continue;
-				}
-
-				/* Don't consider inactive keys, however
-				 * the key may be temporary offline, so do
-				 * consider keys which private key files are
-				 * unavailable.
-				 */
-				if (dst_key_inactive(keys[j])) {
+				if (!dst_key_isprivate(keys[j]))
 					continue;
-				}
-
-				if (REVOKE(keys[j])) {
+				if (dst_key_inactive(keys[j]))	/* SBR */
 					continue;
-				}
-				if (KSK(keys[j])) {
+				if (REVOKE(keys[j]))
+					continue;
+				if (KSK(keys[j]))
 					have_ksk = true;
-				} else {
+				else
 					have_nonksk = true;
-				}
 				both = have_ksk && have_nonksk;
-				if (both) {
+				if (both)
 					break;
-				}
 			}
 		}
 
 		if (both) {
-			if (type == dns_rdatatype_dnskey) {
+			/*
+			 * CDS and CDNSKEY are signed with KSK (RFC 7344, 4.1).
+			 */
+			if (type == dns_rdatatype_dnskey ||
+			    type == dns_rdatatype_cdnskey ||
+			    type == dns_rdatatype_cds)
+			{
 				if (!KSK(keys[i]) && keyset_kskonly)
 					continue;
 			} else if (KSK(keys[i])) {
-				/*
-				 * CDS and CDNSKEY are signed with KSK
-				 * (RFC 7344, 4.1).
-				*/
-				if (type != dns_rdatatype_cds &&
-				    type != dns_rdatatype_cdnskey)
-					continue;
+				continue;
 			}
-		} else if (REVOKE(keys[i]) && type != dns_rdatatype_dnskey)
+		} else if (REVOKE(keys[i]) && type != dns_rdatatype_dnskey) {
 			continue;
+		}
 
 		/* Calculate the signature, creating a RRSIG RDATA. */
 		CHECK(dns_dnssec_sign(name, &rdataset, keys[i],
@@ -1374,34 +1361,13 @@ struct dns_update_state {
 	dns_diff_t work;
 	dst_key_t *zone_keys[DNS_MAXZONEKEYS];
 	unsigned int nkeys;
-	isc_stdtime_t inception, expire, soaexpire;
+	isc_stdtime_t inception, expire;
 	dns_ttl_t nsecttl;
 	bool check_ksk, keyset_kskonly, build_nsec3;
 	enum { sign_updates, remove_orphaned, build_chain, process_nsec,
 	       sign_nsec, update_nsec3, process_nsec3, sign_nsec3 } state;
 };
 
-static uint32_t
-dns__jitter_expire(dns_zone_t *zone, uint32_t sigvalidityinterval) {
-	/* Spread out signatures over time */
-	if (sigvalidityinterval >= 3600U) {
-		uint32_t expiryinterval = dns_zone_getsigresigninginterval(zone);
-		uint32_t jitter;
-		isc_random_get(&jitter);
-
-		if (sigvalidityinterval < 7200U) {
-			expiryinterval = 1200;
-		} else if (expiryinterval > sigvalidityinterval) {
-			expiryinterval = sigvalidityinterval;
-		} else {
-			expiryinterval = sigvalidityinterval - expiryinterval;
-		}
-		jitter %= expiryinterval;
-		sigvalidityinterval -= jitter;
-	}
-	return (sigvalidityinterval);
-}
-
 isc_result_t
 dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 			 dns_dbversion_t *oldver, dns_dbversion_t *newver,
@@ -1455,9 +1421,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 
 		isc_stdtime_get(&now);
 		state->inception = now - 3600; /* Allow for some clock skew. */
-		state->expire = now +
-				dns__jitter_expire(zone, sigvalidityinterval);
-		state->soaexpire = now + sigvalidityinterval;
+		state->expire = now + sigvalidityinterval;
 
 		/*
 		 * Do we look at the KSK flag on the DNSKEY to determining which
@@ -1466,11 +1430,9 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		 * and one doesn't.
 		 */
 		state->check_ksk =
-			((dns_zone_getoptions(zone) &
-			  DNS_ZONEOPT_UPDATECHECKKSK) != 0);
+			(dns_zone_getoptions(zone) & DNS_ZONEOPT_UPDATECHECKKSK);
 		state->keyset_kskonly =
-			((dns_zone_getoptions(zone) &
-			  DNS_ZONEOPT_DNSKEYKSKONLY) != 0);
+			(dns_zone_getoptions(zone) & DNS_ZONEOPT_DNSKEYKSKONLY);
 
 		/*
 		 * Get the NSEC/NSEC3 TTL from the SOA MINIMUM field.
@@ -1555,19 +1517,13 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				CHECK(rrset_visible(db, newver, name, type,
 						   &flag));
 				if (flag) {
-					isc_stdtime_t exp;
-
-					if (type == dns_rdatatype_soa) {
-						exp = state->soaexpire;
-					} else {
-						exp = state->expire;
-					}
 					CHECK(add_sigs(log, zone, db, newver,
 						       name, type,
 						       &state->sig_diff,
 						       state->zone_keys,
 						       state->nkeys,
-						       state->inception, exp,
+						       state->inception,
+						       state->expire,
 						       state->check_ksk,
 						       state->keyset_kskonly));
 					sigs++;
@@ -1851,7 +1807,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				sigs++;
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 			ISC_LIST_UNLINK(state->nsec_mindiff.tuples, t, link);
 			ISC_LIST_APPEND(state->work.tuples, t, link);
@@ -2025,7 +1980,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				sigs++;
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 			ISC_LIST_UNLINK(state->nsec_mindiff.tuples, t, link);
 			ISC_LIST_APPEND(state->work.tuples, t, link);
@@ -2052,7 +2006,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 
  failure:
@@ -2082,12 +2035,16 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 
 static isc_stdtime_t
 epoch_to_yyyymmdd(time_t when) {
-	struct tm t, *tm = localtime_r(&when, &t);
-	if (tm == NULL) {
-		return (0);
-	}
-	return (((tm->tm_year + 1900) * 10000) + ((tm->tm_mon + 1) * 100) +
-		tm->tm_mday);
+	struct tm *tm;
+
+#if defined(ISC_PLATFORM_USETHREADS) && !defined(WIN32)
+	struct tm tm0;
+	tm = localtime_r(&when, &tm0);
+#else
+	tm = localtime(&when);
+#endif
+	return (((tm->tm_year + 1900) * 10000) +
+		((tm->tm_mon + 1) * 100) + tm->tm_mday);
 }
 
 uint32_t
