@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -24,12 +24,8 @@
 #include <isc/types.h>
 
 #if defined(ISC_PLATFORM_HAVESTDATOMIC)
-#if defined (__cplusplus)
-#include <isc/stdatomic.h>
-#else
 #include <stdatomic.h>
 #endif
-#endif
 
 /*! \file isc/refcount.h
  * \brief Implements a locked reference counter.
@@ -99,17 +95,11 @@ ISC_LANG_BEGINDECLS
  * Sample implementations
  */
 #ifdef ISC_PLATFORM_USETHREADS
-
-#if defined(ISC_PLATFORM_HAVESTDATOMIC)
-# define ISC_REFCOUNT_HAVEATOMIC 1
-# define ISC_REFCOUNT_HAVESTDATOMIC 1
-#else /* defined(ISC_PLATFORM_HAVESTDATOMIC) */
-# if defined(ISC_PLATFORM_HAVEXADD)
-#  define ISC_REFCOUNT_HAVEATOMIC 1
-# endif /* defined(ISC_PLATFORM_HAVEXADD */
-#endif /* !defined(ISC_REFCOUNT_HAVEATOMIC) */
-
-#if defined(ISC_REFCOUNT_HAVEATOMIC)
+#if (defined(ISC_PLATFORM_HAVESTDATOMIC) && defined(ATOMIC_INT_LOCK_FREE)) || defined(ISC_PLATFORM_HAVEXADD)
+#define ISC_REFCOUNT_HAVEATOMIC 1
+#if (defined(ISC_PLATFORM_HAVESTDATOMIC) && defined(ATOMIC_INT_LOCK_FREE))
+#define ISC_REFCOUNT_HAVESTDATOMIC 1
+#endif
 
 typedef struct isc_refcount {
 #if defined(ISC_REFCOUNT_HAVESTDATOMIC)
@@ -123,7 +113,7 @@ typedef struct isc_refcount {
 
 #define isc_refcount_current(rp)					\
 	((unsigned int)(atomic_load_explicit(&(rp)->refs,		\
-					     memory_order_acquire)))
+					     memory_order_relaxed)))
 #define isc_refcount_destroy(rp) ISC_REQUIRE(isc_refcount_current(rp) == 0)
 
 #define isc_refcount_increment0(rp, tp)				\
@@ -152,13 +142,13 @@ typedef struct isc_refcount {
 		unsigned int *_tmp = (unsigned int *)(tp);	\
 		int32_t prev;				\
 		prev = atomic_fetch_sub_explicit		\
-			(&(rp)->refs, 1, memory_order_acq_rel); \
+			(&(rp)->refs, 1, memory_order_relaxed); \
 		ISC_REQUIRE(prev > 0);				\
 		if (_tmp != NULL)				\
 			*_tmp = prev - 1;			\
 	} while (0)
 
-#else /* defined(ISC_REFCOUNT_HAVESTDATOMIC) */
+#else /* ISC_REFCOUNT_HAVESTDATOMIC */
 
 #define isc_refcount_current(rp)				\
 	((unsigned int)(isc_atomic_xadd(&(rp)->refs, 0)))
@@ -193,9 +183,9 @@ typedef struct isc_refcount {
 			*_tmp = prev - 1;			\
 	} while (0)
 
-#endif /* defined(ISC_REFCOUNT_HAVESTDATOMIC) */
+#endif /* ISC_REFCOUNT_HAVESTDATOMIC */
 
-#else /* defined(ISC_REFCOUNT_HAVEATOMIC) */
+#else  /* ISC_PLATFORM_HAVEXADD */
 
 typedef struct isc_refcount {
 	int refs;
@@ -262,8 +252,7 @@ typedef struct isc_refcount {
 		ISC_ERROR_RUNTIMECHECK(_result == ISC_R_SUCCESS);	\
 	} while (0)
 
-#endif /* defined(ISC_REFCOUNT_ATOMIC) */
-
+#endif /* (defined(ISC_PLATFORM_HAVESTDATOMIC) && defined(ATOMIC_INT_LOCK_FREE)) || defined(ISC_PLATFORM_HAVEXADD) */
 #else  /* ISC_PLATFORM_USETHREADS */
 
 typedef struct isc_refcount {
