@@ -1,27 +1,21 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
-
-/*! \file
- * \author  Principal Authors: DCL */
+/*! \file */
 
 #include <config.h>
 
 #include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <time.h>
@@ -120,7 +114,7 @@ struct isc_logconfig {
 	unsigned int			duplicate_interval;
 	int				highest_level;
 	char *				tag;
-	isc_boolean_t			dynamic;
+	bool			dynamic;
 };
 
 /*!
@@ -231,14 +225,11 @@ static isc_result_t
 sync_channellist(isc_logconfig_t *lcfg);
 
 static isc_result_t
-greatest_version(isc_logchannel_t *channel, int versions, int *greatest);
-
-static isc_result_t
-roll_log(isc_logchannel_t *channel);
+greatest_version(isc_logfile_t *file, int versions, int *greatest);
 
 static void
 isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
-	     isc_logmodule_t *module, int level, isc_boolean_t write_once,
+	     isc_logmodule_t *module, int level, bool write_once,
 	     isc_msgcat_t *msgcat, int msgset, int msg,
 	     const char *format, va_list args)
      ISC_FORMAT_PRINTF(9, 0);
@@ -252,6 +243,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 #define FILE_NAME(channel)	 (channel->destination.file.name)
 #define FILE_STREAM(channel)	 (channel->destination.file.stream)
 #define FILE_VERSIONS(channel)	 (channel->destination.file.versions)
+#define FILE_SUFFIX(channel)	 (channel->destination.file.suffix)
 #define FILE_MAXSIZE(channel)	 (channel->destination.file.maximum_size)
 #define FILE_MAXREACHED(channel) (channel->destination.file.maximum_reached)
 
@@ -346,7 +338,7 @@ isc_logconfig_create(isc_log_t *lctx, isc_logconfig_t **lcfgp) {
 		lcfg->duplicate_interval = 0;
 		lcfg->highest_level = level;
 		lcfg->tag = NULL;
-		lcfg->dynamic = ISC_FALSE;
+		lcfg->dynamic = false;
 
 		ISC_LIST_INIT(lcfg->channels);
 
@@ -376,6 +368,7 @@ isc_logconfig_create(isc_log_t *lctx, isc_logconfig_t **lcfgp) {
 		destination.file.stream = stderr;
 		destination.file.name = NULL;
 		destination.file.versions = ISC_LOG_ROLLNEVER;
+		destination.file.suffix = isc_log_rollsuffix_increment;
 		destination.file.maximum_size = 0;
 		result = isc_log_createchannel(lcfg, "default_stderr",
 					       ISC_LOG_TOFILEDESC,
@@ -395,6 +388,7 @@ isc_logconfig_create(isc_log_t *lctx, isc_logconfig_t **lcfgp) {
 		destination.file.stream = stderr;
 		destination.file.name = NULL;
 		destination.file.versions = ISC_LOG_ROLLNEVER;
+		destination.file.suffix = isc_log_rollsuffix_increment;
 		destination.file.maximum_size = 0;
 		result = isc_log_createchannel(lcfg, "default_debug",
 					       ISC_LOG_TOFILEDESC,
@@ -552,7 +546,7 @@ isc_logconfig_destroy(isc_logconfig_t **lcfgp) {
 			    lcfg->channellist_count *
 			    sizeof(ISC_LIST(isc_logchannellist_t)));
 
-	lcfg->dynamic = ISC_FALSE;
+	lcfg->dynamic = false;
 	if (lcfg->tag != NULL)
 		isc_mem_free(lcfg->lctx->mctx, lcfg->tag);
 	lcfg->tag = NULL;
@@ -707,6 +701,9 @@ isc_log_createchannel(isc_logconfig_t *lcfg, const char *name,
 {
 	isc_logchannel_t *channel;
 	isc_mem_t *mctx;
+	unsigned int permitted = ISC_LOG_PRINTALL | ISC_LOG_DEBUGONLY |
+				 ISC_LOG_BUFFERED | ISC_LOG_ISO8601 |
+				 ISC_LOG_UTC;
 
 	REQUIRE(VALID_CONFIG(lcfg));
 	REQUIRE(name != NULL);
@@ -714,8 +711,7 @@ isc_log_createchannel(isc_logconfig_t *lcfg, const char *name,
 		type == ISC_LOG_TOFILEDESC || type == ISC_LOG_TONULL);
 	REQUIRE(destination != NULL || type == ISC_LOG_TONULL);
 	REQUIRE(level >= ISC_LOG_CRITICAL);
-	REQUIRE((flags &
-		 (unsigned int)~(ISC_LOG_PRINTALL | ISC_LOG_DEBUGONLY)) == 0);
+	REQUIRE((flags & ~permitted) == 0);
 
 	/* XXXDCL find duplicate names? */
 
@@ -751,8 +747,9 @@ isc_log_createchannel(isc_logconfig_t *lcfg, const char *name,
 			isc_mem_strdup(mctx, destination->file.name);
 		FILE_STREAM(channel) = NULL;
 		FILE_VERSIONS(channel) = destination->file.versions;
+		FILE_SUFFIX(channel) = destination->file.suffix;
 		FILE_MAXSIZE(channel) = destination->file.maximum_size;
-		FILE_MAXREACHED(channel) = ISC_FALSE;
+		FILE_MAXREACHED(channel) = false;
 		break;
 
 	case ISC_LOG_TOFILEDESC:
@@ -760,6 +757,7 @@ isc_log_createchannel(isc_logconfig_t *lcfg, const char *name,
 		FILE_STREAM(channel) = destination->file.stream;
 		FILE_MAXSIZE(channel) = 0;
 		FILE_VERSIONS(channel) = ISC_LOG_ROLLNEVER;
+		FILE_SUFFIX(channel) = isc_log_rollsuffix_increment;
 		break;
 
 	case ISC_LOG_TONULL:
@@ -838,7 +836,7 @@ isc_log_write(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, ISC_FALSE,
+	isc_log_doit(lctx, category, module, level, false,
 		     NULL, 0, 0, format, args);
 	va_end(args);
 }
@@ -851,7 +849,7 @@ isc_log_vwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, ISC_FALSE,
+	isc_log_doit(lctx, category, module, level, false,
 		     NULL, 0, 0, format, args);
 }
 
@@ -866,7 +864,7 @@ isc_log_write1(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, ISC_TRUE,
+	isc_log_doit(lctx, category, module, level, true,
 		     NULL, 0, 0, format, args);
 	va_end(args);
 }
@@ -879,7 +877,7 @@ isc_log_vwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, ISC_TRUE,
+	isc_log_doit(lctx, category, module, level, true,
 		     NULL, 0, 0, format, args);
 }
 
@@ -896,7 +894,7 @@ isc_log_iwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, ISC_FALSE,
+	isc_log_doit(lctx, category, module, level, false,
 		     msgcat, msgset, msg, format, args);
 	va_end(args);
 }
@@ -910,7 +908,7 @@ isc_log_ivwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, ISC_FALSE,
+	isc_log_doit(lctx, category, module, level, false,
 		     msgcat, msgset, msg, format, args);
 }
 
@@ -927,7 +925,7 @@ isc_log_iwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, ISC_TRUE,
+	isc_log_doit(lctx, category, module, level, true,
 		     msgcat, msgset, msg, format, args);
 	va_end(args);
 }
@@ -941,7 +939,7 @@ isc_log_ivwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, ISC_TRUE,
+	isc_log_doit(lctx, category, module, level, true,
 		     msgcat, msgset, msg, format, args);
 }
 
@@ -1093,7 +1091,7 @@ assignchannel(isc_logconfig_t *lcfg, unsigned int category_id,
 		if (lcfg->highest_level < channel->level)
 			lcfg->highest_level = channel->level;
 		if (channel->level == ISC_LOG_DYNAMIC)
-			lcfg->dynamic = ISC_TRUE;
+			lcfg->dynamic = true;
 	}
 
 	return (ISC_R_SUCCESS);
@@ -1141,8 +1139,7 @@ sync_channellist(isc_logconfig_t *lcfg) {
 }
 
 static isc_result_t
-greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
-	/* XXXDCL HIGHLY NT */
+greatest_version(isc_logfile_t *file, int versions, int *greatestp) {
 	char *bname, *digit_end;
 	const char *dirname;
 	int version, greatest = -1;
@@ -1154,15 +1151,13 @@ greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
 	char *bname2;
 #endif
 
-	REQUIRE(channel->type == ISC_LOG_TOFILE);
-
 	/*
 	 * It is safe to DE_CONST the file.name because it was copied
-	 * with isc_mem_strdup in isc_log_createchannel.
+	 * with isc_mem_strdup().
 	 */
-	bname = strrchr(FILE_NAME(channel), sep);
+	bname = strrchr(file->name, sep);
 #ifdef _WIN32
-	bname2 = strrchr(FILE_NAME(channel), '\\');
+	bname2 = strrchr(file->name, '\\');
 	if ((bname != NULL && bname2 != NULL && bname2 > bname) ||
 	    (bname == NULL && bname2 != NULL)) {
 		bname = bname2;
@@ -1171,9 +1166,9 @@ greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
 #endif
 	if (bname != NULL) {
 		*bname++ = '\0';
-		dirname = FILE_NAME(channel);
+		dirname = file->name;
 	} else {
-		DE_CONST(FILE_NAME(channel), bname);
+		DE_CONST(file->name, bname);
 		dirname = ".";
 	}
 	bnamelen = strlen(bname);
@@ -1184,7 +1179,7 @@ greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
 	/*
 	 * Replace the file separator if it was taken out.
 	 */
-	if (bname != FILE_NAME(channel))
+	if (bname != file->name)
 		*(bname - 1) = sep;
 
 	/*
@@ -1196,8 +1191,8 @@ greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
 	while (isc_dir_read(&dir) == ISC_R_SUCCESS) {
 		if (dir.entry.length > bnamelen &&
 		    strncmp(dir.entry.name, bname, bnamelen) == 0 &&
-		    dir.entry.name[bnamelen] == '.') {
-
+		    dir.entry.name[bnamelen] == '.')
+		{
 			version = strtol(&dir.entry.name[bnamelen + 1],
 					 &digit_end, 10);
 			/*
@@ -1223,24 +1218,138 @@ greatest_version(isc_logchannel_t *channel, int versions, int *greatestp) {
 }
 
 static isc_result_t
-roll_log(isc_logchannel_t *channel) {
+remove_old_tsversions(isc_logfile_t *file, int versions) {
+	isc_result_t result;
+	char *bname, *digit_end;
+	const char *dirname;
+	int64_t version, last = INT64_MAX;
+	int64_t to_keep[ISC_LOG_MAX_VERSIONS];
+	size_t bnamelen;
+	isc_dir_t dir;
+	char sep = '/';
+#ifdef _WIN32
+	char *bname2;
+#endif
+	/*
+	 * It is safe to DE_CONST the file.name because it was copied
+	 * with isc_mem_strdup().
+	 */
+	bname = strrchr(file->name, sep);
+#ifdef _WIN32
+	bname2 = strrchr(file->name, '\\');
+	if ((bname != NULL && bname2 != NULL && bname2 > bname) ||
+	    (bname == NULL && bname2 != NULL)) {
+		bname = bname2;
+		sep = '\\';
+	}
+#endif
+	if (bname != NULL) {
+		*bname++ = '\0';
+		dirname = file->name;
+	} else {
+		DE_CONST(file->name, bname);
+		dirname = ".";
+	}
+	bnamelen = strlen(bname);
+
+	isc_dir_init(&dir);
+	result = isc_dir_open(&dir, dirname);
+
+	/*
+	 * Replace the file separator if it was taken out.
+	 */
+	if (bname != file->name) {
+		*(bname - 1) = sep;
+	}
+
+	/*
+	 * Return if the directory open failed.
+	 */
+	if (result != ISC_R_SUCCESS)
+		return (result);
+
+	if (versions > 0) {
+		/*
+		 * First we fill 'to_keep' structure using insertion sort
+		 */
+		memset(to_keep, 0, versions * sizeof(long long));
+		while (isc_dir_read(&dir) == ISC_R_SUCCESS) {
+			if (dir.entry.length > bnamelen &&
+			    strncmp(dir.entry.name, bname, bnamelen) == 0 &&
+			    dir.entry.name[bnamelen] == '.')
+			{
+				char *ename = &dir.entry.name[bnamelen + 1];
+				version = isc_string_touint64(ename,
+							      &digit_end, 10);
+				if (*digit_end == '\0') {
+					int i = 0;
+					while (i < versions &&
+					       version < to_keep[i])
+					{
+						i++;
+					}
+					if (i < versions) {
+						memmove(&to_keep[i + 1],
+							&to_keep[i],
+							sizeof(long long) *
+							versions - i - 1);
+						to_keep[i] = version;
+					}
+				}
+			}
+		}
+
+		/*
+		 * to_keep[versions - 1] is the last one we want to keep
+		 */
+		last = to_keep[versions - 1];
+		isc_dir_reset(&dir);
+	}
+
+	/*
+	 * Then we remove all files that we don't want to_keep
+	 */
+	while (isc_dir_read(&dir) == ISC_R_SUCCESS) {
+		if (dir.entry.length > bnamelen &&
+		    strncmp(dir.entry.name, bname, bnamelen) == 0 &&
+		    dir.entry.name[bnamelen] == '.')
+		{
+			char *ename = &dir.entry.name[bnamelen + 1];
+			version = isc_string_touint64(ename, &digit_end, 10);
+			/*
+			 * Remove any backup files that exceed versions.
+			 */
+			if (*digit_end == '\0' && version < last) {
+				result = isc_file_remove(dir.entry.name);
+				if (result != ISC_R_SUCCESS &&
+				    result != ISC_R_FILENOTFOUND)
+					syslog(LOG_ERR, "unable to remove "
+					       "log file '%s': %s",
+					       dir.entry.name,
+					       isc_result_totext(result));
+			}
+		}
+	}
+
+	isc_dir_close(&dir);
+
+	return (ISC_R_SUCCESS);
+}
+
+static isc_result_t
+roll_increment(isc_logfile_t *file) {
 	int i, n, greatest;
 	char current[PATH_MAX + 1];
 	char newpath[PATH_MAX + 1];
 	const char *path;
-	isc_result_t result;
+	isc_result_t result = ISC_R_SUCCESS;
 
-	/*
-	 * Do nothing (not even excess version trimming) if ISC_LOG_ROLLNEVER
-	 * is specified.  Apparently complete external control over the log
-	 * files is desired.
-	 */
-	if (FILE_VERSIONS(channel) == ISC_LOG_ROLLNEVER)
-		return (ISC_R_SUCCESS);
+	REQUIRE(file != NULL);
+	REQUIRE(file->versions != 0);
 
-	path = FILE_NAME(channel);
+	path = file->name;
 
-	if (FILE_VERSIONS(channel) == ISC_LOG_ROLLINFINITE) {
+	if (file->versions == ISC_LOG_ROLLINFINITE) {
 		/*
 		 * Find the first missing entry in the log file sequence.
 		 */
@@ -1249,23 +1358,26 @@ roll_log(isc_logchannel_t *channel) {
 				     "%s.%u", path, (unsigned)greatest) ;
 			if (n >= (int)sizeof(current) || n < 0 ||
 			    !isc_file_exists(current))
+			{
 				break;
+			}
 		}
 	} else {
 		/*
 		 * Get the largest existing version and remove any
 		 * version greater than the permitted version.
 		 */
-		result = greatest_version(channel, FILE_VERSIONS(channel),
-					  &greatest);
-		if (result != ISC_R_SUCCESS)
+		result = greatest_version(file, file->versions, &greatest);
+		if (result != ISC_R_SUCCESS) {
 			return (result);
+		}
 
 		/*
 		 * Increment if greatest is not the actual maximum value.
 		 */
-		if (greatest < FILE_VERSIONS(channel) - 1)
+		if (greatest < file->versions - 1) {
 			greatest++;
+		}
 	}
 
 	for (i = greatest; i > 0; i--) {
@@ -1282,43 +1394,111 @@ roll_log(isc_logchannel_t *channel) {
 				result = ISC_R_NOSPACE;
 			}
 		}
-		if (result == ISC_R_SUCCESS)
+		if (result == ISC_R_SUCCESS) {
 			result = isc_file_rename(current, newpath);
-		if (result != ISC_R_SUCCESS &&
-		    result != ISC_R_FILENOTFOUND)
+		}
+		if (result != ISC_R_SUCCESS && result != ISC_R_FILENOTFOUND) {
 			syslog(LOG_ERR,
 			       "unable to rename log file '%s.%u' to "
 			       "'%s.%u': %s", path, i - 1, path, i,
 			       isc_result_totext(result));
+		}
 	}
 
-	if (FILE_VERSIONS(channel) != 0) {
-		n = snprintf(newpath, sizeof(newpath), "%s.0", path);
-		if (n >= (int)sizeof(newpath) || n < 0)
-			result = ISC_R_NOSPACE;
-		else
-			result = isc_file_rename(path, newpath);
-		if (result != ISC_R_SUCCESS &&
-		    result != ISC_R_FILENOTFOUND)
-			syslog(LOG_ERR,
-			       "unable to rename log file '%s' to '%s.0': %s",
-			       path, path, isc_result_totext(result));
+	n = snprintf(newpath, sizeof(newpath), "%s.0", path);
+	if (n >= (int)sizeof(newpath) || n < 0) {
+		result = ISC_R_NOSPACE;
 	} else {
-		result = isc_file_remove(path);
-		if (result != ISC_R_SUCCESS &&
-		    result != ISC_R_FILENOTFOUND)
-			syslog(LOG_ERR, "unable to remove log file '%s': %s",
-			       path, isc_result_totext(result));
+		result = isc_file_rename(path, newpath);
+	}
+	if (result != ISC_R_SUCCESS && result != ISC_R_FILENOTFOUND) {
+		syslog(LOG_ERR,
+		       "unable to rename log file '%s' to '%s.0': %s",
+		       path, path, isc_result_totext(result));
 	}
 
 	return (ISC_R_SUCCESS);
 }
 
+static isc_result_t
+roll_timestamp(isc_logfile_t *file) {
+	int n;
+	char newts[PATH_MAX + 1];
+	char newpath[PATH_MAX + 1];
+	const char *path;
+	isc_time_t now;
+	isc_result_t result = ISC_R_SUCCESS;
+
+	REQUIRE(file != NULL);
+	REQUIRE(file->versions != 0);
+
+	path = file->name;
+
+	/*
+	 * First find all the logfiles and remove the oldest ones
+	 * Save one fewer than file->versions because we'll be renaming
+	 * the existing file to a timestamped version after this.
+	 */
+	if (file->versions != ISC_LOG_ROLLINFINITE) {
+		remove_old_tsversions(file, file->versions - 1);
+	}
+
+	/* Then just rename the current logfile */
+	isc_time_now(&now);
+	isc_time_formatshorttimestamp(&now, newts, PATH_MAX + 1);
+	n = snprintf(newpath, sizeof(newpath), "%s.%s", path, newts);
+	if (n >= (int)sizeof(newpath) || n < 0) {
+		result = ISC_R_NOSPACE;
+	} else {
+		result = isc_file_rename(path, newpath);
+	}
+	if (result != ISC_R_SUCCESS && result != ISC_R_FILENOTFOUND) {
+		syslog(LOG_ERR,
+		       "unable to rename log file '%s' to '%s.0': %s",
+		       path, path, isc_result_totext(result));
+	}
+
+	return (ISC_R_SUCCESS);
+}
+
+
+isc_result_t
+isc_logfile_roll(isc_logfile_t *file) {
+	isc_result_t result;
+
+	REQUIRE(file != NULL);
+
+	/*
+	 * Do nothing (not even excess version trimming) if ISC_LOG_ROLLNEVER
+	 * is specified.  Apparently complete external control over the log
+	 * files is desired.
+	 */
+	if (file->versions == ISC_LOG_ROLLNEVER) {
+		return (ISC_R_SUCCESS);
+	} else if (file->versions == 0) {
+		result = isc_file_remove(file->name);
+		if (result != ISC_R_SUCCESS &&
+		    result != ISC_R_FILENOTFOUND)
+			syslog(LOG_ERR, "unable to remove log file '%s': %s",
+			       file->name, isc_result_totext(result));
+		return (ISC_R_SUCCESS);
+	}
+
+	switch (file->suffix) {
+	case isc_log_rollsuffix_increment:
+		return (roll_increment(file));
+	case isc_log_rollsuffix_timestamp:
+		return (roll_timestamp(file));
+	default:
+		return (ISC_R_UNEXPECTED);
+	}
+}
+
 static isc_result_t
 isc_log_open(isc_logchannel_t *channel) {
 	struct stat statbuf;
-	isc_boolean_t regular_file;
-	isc_boolean_t roll = ISC_FALSE;
+	bool regular_file;
+	bool roll = false;
 	isc_result_t result = ISC_R_SUCCESS;
 	const char *path;
 
@@ -1335,7 +1515,7 @@ isc_log_open(isc_logchannel_t *channel) {
 	 * and either has no size limit or has reached its size limit.
 	 */
 	if (stat(path, &statbuf) == 0) {
-		regular_file = S_ISREG(statbuf.st_mode) ? ISC_TRUE : ISC_FALSE;
+		regular_file = S_ISREG(statbuf.st_mode) ? true : false;
 		/* XXXDCL if not regular_file complain? */
 		if ((FILE_MAXSIZE(channel) == 0 &&
 		     FILE_VERSIONS(channel) != ISC_LOG_ROLLNEVER) ||
@@ -1343,7 +1523,7 @@ isc_log_open(isc_logchannel_t *channel) {
 		     statbuf.st_size >= FILE_MAXSIZE(channel)))
 			roll = regular_file;
 	} else if (errno == ENOENT) {
-		regular_file = ISC_TRUE;
+		regular_file = true;
 		POST(regular_file);
 	} else
 		result = ISC_R_INVALIDFILE;
@@ -1354,11 +1534,11 @@ isc_log_open(isc_logchannel_t *channel) {
 	if (result == ISC_R_SUCCESS && roll) {
 		if (FILE_VERSIONS(channel) == ISC_LOG_ROLLNEVER)
 			return (ISC_R_MAXSIZE);
-		result = roll_log(channel);
+		result = isc_logfile_roll(&channel->destination.file);
 		if (result != ISC_R_SUCCESS) {
 			if ((channel->flags & ISC_LOG_OPENERR) == 0) {
 				syslog(LOG_ERR,
-				       "isc_log_open: roll_log '%s' "
+				       "isc_log_open: isc_logfile_roll '%s' "
 				       "failed: %s",
 				       FILE_NAME(channel),
 				       isc_result_totext(result));
@@ -1373,7 +1553,7 @@ isc_log_open(isc_logchannel_t *channel) {
 	return (result);
 }
 
-isc_boolean_t
+bool
 isc_log_wouldlog(isc_log_t *lctx, int level) {
 	/*
 	 * Try to avoid locking the mutex for messages which can't
@@ -1393,27 +1573,30 @@ isc_log_wouldlog(isc_log_t *lctx, int level) {
 	 */
 
 	if (lctx == NULL || lctx->logconfig == NULL)
-		return (ISC_FALSE);
+		return (false);
 
-	return (ISC_TF(level <= lctx->logconfig->highest_level ||
-		       (lctx->logconfig->dynamic &&
-			level <= lctx->debug_level)));
+	return (level <= lctx->logconfig->highest_level ||
+		(lctx->logconfig->dynamic &&
+		 level <= lctx->debug_level));
 }
 
 static void
 isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
-	     isc_logmodule_t *module, int level, isc_boolean_t write_once,
+	     isc_logmodule_t *module, int level, bool write_once,
 	     isc_msgcat_t *msgcat, int msgset, int msg,
 	     const char *format, va_list args)
 {
 	int syslog_level;
-	char time_string[64];
+	const char *time_string;
+	char local_time[64];
+	char iso8601z_string[64];
+	char iso8601l_string[64];
 	char level_string[24];
 	const char *iformat;
 	struct stat statbuf;
-	isc_boolean_t matched = ISC_FALSE;
-	isc_boolean_t printtime, printtag, printcolon;
-	isc_boolean_t printcategory, printmodule, printlevel;
+	bool matched = false;
+	bool printtime, iso8601, utc, printtag, printcolon;
+	bool printcategory, printmodule, printlevel, buffered;
 	isc_logconfig_t *lcfg;
 	isc_logchannel_t *channel;
 	isc_logchannellist_t *category_channels;
@@ -1444,7 +1627,9 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 	else
 		iformat = format;
 
-	time_string[0]  = '\0';
+	local_time[0] = '\0';
+	iso8601l_string[0] = '\0';
+	iso8601z_string[0] = '\0';
 	level_string[0] = '\0';
 
 	LOCK(&lctx->lock);
@@ -1491,7 +1676,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 			continue;
 		}
 
-		matched = ISC_TRUE;
+		matched = true;
 
 		channel = category_channels->channel;
 		category_channels = ISC_LIST_NEXT(category_channels, link);
@@ -1507,12 +1692,21 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 			continue;
 
 		if ((channel->flags & ISC_LOG_PRINTTIME) != 0 &&
-		    time_string[0] == '\0') {
+		    local_time[0] == '\0')
+		{
 			isc_time_t isctime;
 
 			TIME_NOW(&isctime);
-			isc_time_formattimestamp(&isctime, time_string,
-						 sizeof(time_string));
+
+			isc_time_formattimestamp(&isctime,
+						 local_time,
+						 sizeof(local_time));
+			isc_time_formatISO8601ms(&isctime,
+						 iso8601z_string,
+						 sizeof(iso8601z_string));
+			isc_time_formatISO8601Lms(&isctime,
+						  iso8601l_string,
+						  sizeof(iso8601l_string));
 		}
 
 		if ((channel->flags & ISC_LOG_PRINTLEVEL) != 0 &&
@@ -1643,19 +1837,31 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 			}
 		}
 
-		printtime     = ISC_TF((channel->flags & ISC_LOG_PRINTTIME)
-				       != 0);
-		printtag      = ISC_TF((channel->flags &
-					(ISC_LOG_PRINTTAG|ISC_LOG_PRINTPREFIX))
-				       != 0 && lcfg->tag != NULL);
-		printcolon    = ISC_TF((channel->flags & ISC_LOG_PRINTTAG)
-				       != 0 && lcfg->tag != NULL);
-		printcategory = ISC_TF((channel->flags & ISC_LOG_PRINTCATEGORY)
-				       != 0);
-		printmodule   = ISC_TF((channel->flags & ISC_LOG_PRINTMODULE)
-				       != 0);
-		printlevel    = ISC_TF((channel->flags & ISC_LOG_PRINTLEVEL)
-				       != 0);
+		utc	      = (channel->flags & ISC_LOG_UTC);
+		iso8601       = (channel->flags & ISC_LOG_ISO8601);
+		printtime     = (channel->flags & ISC_LOG_PRINTTIME);
+		printtag      = ((channel->flags &
+				  (ISC_LOG_PRINTTAG|ISC_LOG_PRINTPREFIX))
+				 && lcfg->tag != NULL);
+		printcolon    = ((channel->flags & ISC_LOG_PRINTTAG)
+				 && lcfg->tag != NULL);
+		printcategory = (channel->flags & ISC_LOG_PRINTCATEGORY);
+		printmodule   = (channel->flags & ISC_LOG_PRINTMODULE);
+		printlevel    = (channel->flags & ISC_LOG_PRINTLEVEL);
+		buffered      = (channel->flags & ISC_LOG_BUFFERED);
+
+		if (printtime) {
+			if (iso8601) {
+				if (utc) {
+					time_string = iso8601z_string;
+				} else {
+					time_string = iso8601l_string;
+				}
+			} else {
+				time_string = local_time;
+			}
+		} else
+			time_string = "";
 
 		switch (channel->type) {
 		case ISC_LOG_TOFILE:
@@ -1676,7 +1882,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 				    statbuf.st_size < FILE_MAXSIZE(channel)) {
 					(void)fclose(FILE_STREAM(channel));
 					FILE_STREAM(channel) = NULL;
-					FILE_MAXREACHED(channel) = ISC_FALSE;
+					FILE_MAXREACHED(channel) = false;
 				} else
 					/*
 					 * Eh, skip it.
@@ -1717,7 +1923,8 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 				printlevel    ? level_string	: "",
 				lctx->buffer);
 
-			fflush(FILE_STREAM(channel));
+			if (!buffered)
+				fflush(FILE_STREAM(channel));
 
 			/*
 			 * If the file now exceeds its maximum size
@@ -1732,7 +1939,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 				if (fstat(fileno(FILE_STREAM(channel)),
 					  &statbuf) >= 0 &&
 				    statbuf.st_size > FILE_MAXSIZE(channel))
-					FILE_MAXREACHED(channel) = ISC_TRUE;
+					FILE_MAXREACHED(channel) = true;
 			}
 
 			break;
