@@ -322,14 +322,16 @@ pk11_rand_seed_fromfile(const char *randomfile) {
 	ret = isc_stdio_open(randomfile, "r", &stream);
 	if (ret != ISC_R_SUCCESS)
 		goto cleanup;
-	ret = isc_stdio_read(seed, 1, SEEDSIZE, stream, &cc);
-	if (ret!= ISC_R_SUCCESS)
-		goto cleanup;
+	while (ret == ISC_R_SUCCESS) {
+		ret = isc_stdio_read(seed, 1, SEEDSIZE, stream, &cc);
+		if ((ret != ISC_R_SUCCESS) && (ret != ISC_R_EOF))
+			goto cleanup;
+		(void) pkcs_C_SeedRandom(ctx.session, seed, (CK_ULONG) cc);
+	}
 	ret = isc_stdio_close(stream);
 	stream = NULL;
-	if (ret!= ISC_R_SUCCESS)
+	if (ret != ISC_R_SUCCESS)
 		goto cleanup;
-	(void) pkcs_C_SeedRandom(ctx.session, seed, (CK_ULONG) cc);
 
     cleanup:
 	if (stream != NULL)
@@ -962,15 +964,13 @@ pk11_get_best_token(pk11_optype_t optype) {
 	return (token->slotid);
 }
 
-isc_result_t
-pk11_numbits(CK_BYTE_PTR data, unsigned int bytecnt, unsigned int *bits) {
+unsigned int
+pk11_numbits(CK_BYTE_PTR data, unsigned int bytecnt) {
 	unsigned int bitcnt, i;
 	CK_BYTE top;
 
-	if (bytecnt == 0) {
-		*bits = 0;
-		return (ISC_R_SUCCESS);
-	}
+	if (bytecnt == 0)
+		return (0);
 	bitcnt = bytecnt * 8;
 	for (i = 0; i < bytecnt; i++) {
 		top = data[i];
@@ -978,41 +978,25 @@ pk11_numbits(CK_BYTE_PTR data, unsigned int bytecnt, unsigned int *bits) {
 			bitcnt -= 8;
 			continue;
 		}
-		if (top & 0x80) {
-			*bits = bitcnt;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x40) {
-			*bits = bitcnt - 1;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x20) {
-			*bits = bitcnt - 2;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x10) {
-			*bits = bitcnt - 3;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x08) {
-			*bits = bitcnt - 4;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x04) {
-			*bits = bitcnt - 5;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x02) {
-			*bits = bitcnt - 6;
-			return (ISC_R_SUCCESS);
-		}
-		if (top & 0x01) {
-			*bits = bitcnt - 7;
-			return (ISC_R_SUCCESS);
-		}
+		if (top & 0x80)
+			return (bitcnt);
+		if (top & 0x40)
+			return (bitcnt - 1);
+		if (top & 0x20)
+			return (bitcnt - 2);
+		if (top & 0x10)
+			return (bitcnt - 3);
+		if (top & 0x08)
+			return (bitcnt - 4);
+		if (top & 0x04)
+			return (bitcnt - 5);
+		if (top & 0x02)
+			return (bitcnt - 6);
+		if (top & 0x01)
+			return (bitcnt - 7);
 		break;
 	}
-	return (ISC_R_RANGE);
+	INSIST(0);
 }
 
 CK_ATTRIBUTE *
@@ -1148,17 +1132,13 @@ push_attribute(pk11_object_t *obj, isc_mem_t *mctx, size_t len) {
 	CK_ATTRIBUTE *attr;
 	CK_BYTE cnt = obj->attrcnt;
 
-	REQUIRE(old != NULL || cnt == 0);
-
 	obj->repr = isc_mem_get(mctx, (cnt + 1) * sizeof(*attr));
 	if (obj->repr == NULL) {
 		obj->repr = old;
 		return (NULL);
 	}
 	memset(obj->repr, 0, (cnt + 1) * sizeof(*attr));
-	if (old != NULL) {
-		memmove(obj->repr, old, cnt * sizeof(*attr));
-	}
+	memmove(obj->repr, old, cnt * sizeof(*attr));
 	attr = obj->repr + cnt;
 	attr->ulValueLen = (CK_ULONG) len;
 	attr->pValue = isc_mem_get(mctx, len);
@@ -1414,7 +1394,6 @@ pk11_dump_tokens(void) {
 			if (!first)
 				printf(",");
 			first = false;
-			UNUSED(first);
 			printf("AES");
 		}
 		printf(")\n");
