@@ -53,7 +53,6 @@
  */
 #ifndef ISC_PLATFORM_USETHREADS
 #include "../timer_p.h"
-#include "../task_p.h"
 #include "socket_p.h"
 #endif /* ISC_PLATFORM_USETHREADS */
 
@@ -101,19 +100,19 @@ typedef struct isc__appctx {
 	isc_mem_t		*mctx;
 	isc_mutex_t		lock;
 	isc_eventlist_t		on_run;
-	bool			shutdown_requested;
-	bool			running;
+	bool		shutdown_requested;
+	bool		running;
 
 	/*!
 	 * We assume that 'want_shutdown' can be read and written atomically.
 	 */
-	bool			want_shutdown;
+	bool		want_shutdown;
 	/*
 	 * We assume that 'want_reload' can be read and written atomically.
 	 */
-	bool			want_reload;
+	bool		want_reload;
 
-	bool			blocked;
+	bool		blocked;
 
 	isc_taskmgr_t		*taskmgr;
 	isc_socketmgr_t		*socketmgr;
@@ -578,6 +577,7 @@ isc__nothread_signal_hack(isc_condition_t *cp) {
 isc_result_t
 isc__app_ctxrun(isc_appctx_t *ctx0) {
 	isc__appctx_t *ctx = (isc__appctx_t *)ctx0;
+	int result;
 	isc_event_t *event, *next_event;
 	isc_task_t *task;
 #ifdef ISC_PLATFORM_USETHREADS
@@ -617,18 +617,15 @@ isc__app_ctxrun(isc_appctx_t *ctx0) {
 	UNLOCK(&ctx->lock);
 
 #ifndef ISC_PLATFORM_USETHREADS
-	{
-		isc_result_t result;
-		if (isc_bind9 && ctx == &isc_g_appctx) {
-			result = handle_signal(SIGHUP, reload_action);
-			if (result != ISC_R_SUCCESS)
-				return (ISC_R_SUCCESS);
-		}
-
-		(void) isc__taskmgr_dispatch(ctx->taskmgr);
-		result = evloop(ctx);
-		return (result);
+	if (isc_bind9 && ctx == &isc_g_appctx) {
+		result = handle_signal(SIGHUP, reload_action);
+		if (result != ISC_R_SUCCESS)
+			return (ISC_R_SUCCESS);
 	}
+
+	(void) isc__taskmgr_dispatch(ctx->taskmgr);
+	result = evloop(ctx);
+	return (result);
 #else /* ISC_PLATFORM_USETHREADS */
 	/*
 	 * BIND9 internal tools using multiple contexts do not
@@ -662,12 +659,14 @@ isc__app_ctxrun(isc_appctx_t *ctx0) {
 			}
 
 #ifndef HAVE_UNIXWARE_SIGWAIT
-			if (sigwait(&sset, &sig) == 0) {
+			result = sigwait(&sset, &sig);
+			if (result == 0) {
 				if (sig == SIGINT || sig == SIGTERM)
 					ctx->want_shutdown = true;
 				else if (sig == SIGHUP)
 					ctx->want_reload = true;
 			}
+
 #else /* Using UnixWare sigwait semantics. */
 			sig = sigwait(&sset);
 			if (sig >= 0) {
@@ -694,7 +693,6 @@ isc__app_ctxrun(isc_appctx_t *ctx0) {
 		}
 #else  /* Don't have sigwait(). */
 		if (isc_bind9) {
-			isc_result_t result;
 			/*
 			 * BIND9 internal; single context:
 			 * Install a signal handler for SIGHUP, then wait for
