@@ -27,7 +27,6 @@
 #include <isc/netaddr.h>
 #include <isc/netscope.h>
 #include <isc/print.h>
-#include <isc/refcount.h>
 #include <isc/string.h>
 #include <isc/sockaddr.h>
 #include <isc/symtab.h>
@@ -233,7 +232,7 @@ cfg_printx(const cfg_obj_t *obj, unsigned int flags,
 isc_result_t
 cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	isc_result_t result;
-	const cfg_tuplefielddef_t *fields;
+	const cfg_tuplefielddef_t *fields = type->of;
 	const cfg_tuplefielddef_t *f;
 	cfg_obj_t *obj = NULL;
 	unsigned int nfields = 0;
@@ -243,8 +242,6 @@ cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
-	fields = type->of;
-
 	for (f = fields; f->name != NULL; f++)
 		nfields++;
 
@@ -270,7 +267,7 @@ isc_result_t
 cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
 	isc_result_t result;
-	const cfg_tuplefielddef_t *fields;
+	const cfg_tuplefielddef_t *fields = type->of;
 	const cfg_tuplefielddef_t *f;
 	cfg_obj_t *obj = NULL;
 	unsigned int i;
@@ -279,8 +276,6 @@ cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
-	fields = type->of;
-
 	CHECK(cfg_create_tuple(pctx, type, &obj));
 	for (f = fields, i = 0; f->name != NULL; f++, i++)
 		CHECK(cfg_parse_obj(pctx, f->type, &obj->value.tuple[i]));
@@ -373,7 +368,7 @@ cfg_tuple_get(const cfg_obj_t *tupleobj, const char* name) {
 			return (tupleobj->value.tuple[i]);
 	}
 	INSIST(0);
-	ISC_UNREACHABLE();
+	return (NULL);
 }
 
 isc_result_t
@@ -1542,15 +1537,13 @@ cfg_parse_spacelist(cfg_parser_t *pctx, const cfg_type_t *listtype,
 		    cfg_obj_t **ret)
 {
 	cfg_obj_t *listobj = NULL;
-	const cfg_type_t *listof;
+	const cfg_type_t *listof = listtype->of;
 	isc_result_t result;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(listtype != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
-	listof = listtype->of;
-
 	CHECK(cfg_create_list(pctx, listtype, &listobj));
 
 	for (;;) {
@@ -1654,7 +1647,7 @@ cfg_listelt_value(const cfg_listelt_t *elt) {
 isc_result_t
 cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
-	const cfg_clausedef_t * const *clausesets;
+	const cfg_clausedef_t * const *clausesets = type->of;
 	isc_result_t result;
 	const cfg_clausedef_t * const *clauseset;
 	const cfg_clausedef_t *clause;
@@ -1669,8 +1662,6 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
-	clausesets = type->of;
-
 	CHECK(create_map(pctx, type, &obj));
 
 	obj->value.map.clausesets = clausesets;
@@ -1812,8 +1803,7 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 			/* Single-valued clause */
 			if (result == ISC_R_NOTFOUND) {
 				bool callback =
-					((clause->flags &
-					  CFG_CLAUSEFLAG_CALLBACK) != 0);
+					(clause->flags & CFG_CLAUSEFLAG_CALLBACK);
 				CHECK(parse_symtab_elt(pctx, clause->name,
 						       clause->type,
 						       obj->value.map.symtab,
@@ -1958,6 +1948,7 @@ print_symval(cfg_printer_t *pctx, const char *name, cfg_obj_t *obj) {
 
 void
 cfg_print_mapbody(cfg_printer_t *pctx, const cfg_obj_t *obj) {
+	isc_result_t result = ISC_R_SUCCESS;
 	const cfg_clausedef_t * const *clauseset;
 
 	REQUIRE(pctx != NULL);
@@ -1973,7 +1964,6 @@ cfg_print_mapbody(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 		for (clause = *clauseset;
 		     clause->name != NULL;
 		     clause++) {
-			isc_result_t result;
 			result = isc_symtab_lookup(obj->value.map.symtab,
 						   clause->name, 0, &symval);
 			if (result == ISC_R_SUCCESS) {
@@ -1998,7 +1988,6 @@ cfg_print_mapbody(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 				; /* do nothing */
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 		}
 	}
@@ -2314,7 +2303,6 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 			return (ISC_R_SUCCESS);
 		} else {
 			INSIST(0);
-			ISC_UNREACHABLE();
 		}
 	} else {
 		if ((flags & (CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK)) != 0) {
@@ -2332,7 +2320,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 				strlcat(buf, ".0", sizeof(buf));
 				if (inet_pton(AF_INET, buf, &in4a) == 1) {
 					isc_netaddr_fromin(na, &in4a);
-					return (ISC_R_IPV4PREFIX);
+					return (ISC_R_SUCCESS);
 				}
 			}
 		}
@@ -2412,7 +2400,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX);
+	return (result == ISC_R_SUCCESS);
 }
 
 isc_result_t
@@ -2516,29 +2504,27 @@ static void
 cfg_doc_netaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	const unsigned int *flagp = type->of;
 	int n = 0;
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
 		cfg_print_cstr(pctx, "( ");
-	}
-	if ((*flagp & CFG_ADDR_V4OK) != 0) {
+	if (*flagp & CFG_ADDR_V4OK) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_V6OK) != 0) {
+	if (*flagp & CFG_ADDR_V6OK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
 		n++;
 		POST(n);
 	}
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
 		cfg_print_cstr(pctx, " )");
-	}
 }
 
 LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_netaddr = {
@@ -2576,18 +2562,14 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 	isc_result_t result;
 	isc_netaddr_t netaddr;
 	unsigned int addrlen = 0, prefixlen;
-	bool expectprefix;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
 	UNUSED(type);
 
-	result = cfg_parse_rawaddr(pctx, CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK |
-				   CFG_ADDR_V6OK, &netaddr);
-	if (result != ISC_R_SUCCESS && result != ISC_R_IPV4PREFIX) {
-		CHECK(result);
-	}
+	CHECK(cfg_parse_rawaddr(pctx, CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK |
+				CFG_ADDR_V6OK, &netaddr));
 	switch (netaddr.family) {
 	case AF_INET:
 		addrlen = 32;
@@ -2597,9 +2579,8 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
-	expectprefix = (result == ISC_R_IPV4PREFIX);
 	CHECK(cfg_peektoken(pctx, 0));
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == '/') {
@@ -2607,30 +2588,16 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_gettoken(pctx, ISC_LEXOPT_NUMBER));
 		if (pctx->token.type != isc_tokentype_number) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
-					 "expected prefix length");
+				     "expected prefix length");
 			return (ISC_R_UNEXPECTEDTOKEN);
 		}
 		prefixlen = pctx->token.value.as_ulong;
 		if (prefixlen > addrlen) {
 			cfg_parser_error(pctx, CFG_LOG_NOPREP,
-					 "invalid prefix length");
+				     "invalid prefix length");
 			return (ISC_R_RANGE);
 		}
-		result = isc_netaddr_prefixok(&netaddr, prefixlen);
-		if (result != ISC_R_SUCCESS) {
-			char buf[ISC_NETADDR_FORMATSIZE + 1];
-			isc_netaddr_format(&netaddr, buf, sizeof(buf));
-			cfg_parser_error(pctx, CFG_LOG_NOPREP,
-					 "'%s/%u': address/prefix length "
-					 "mismatch", buf, prefixlen);
-			return (ISC_R_FAILURE);
-		}
 	} else {
-		if (expectprefix) {
-			cfg_parser_error(pctx, CFG_LOG_NEAR,
-					 "incomplete IPv4 address or prefix");
-			return (ISC_R_FAILURE);
-		}
 		prefixlen = addrlen;
 	}
 	CHECK(cfg_create_obj(pctx, &cfg_type_netprefix, &obj));
@@ -2778,26 +2745,24 @@ cfg_print_sockaddr(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 
 void
 cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
-	const unsigned int *flagp;
+	const unsigned int *flagp = type->of;
 	int n = 0;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(type != NULL);
 
-	flagp = type->of;
-
 	cfg_print_cstr(pctx, "( ");
-	if ((*flagp & CFG_ADDR_V4OK) != 0) {
+	if (*flagp & CFG_ADDR_V4OK) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_V6OK) != 0) {
+	if (*flagp & CFG_ADDR_V6OK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
@@ -2805,7 +2770,7 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 		POST(n);
 	}
 	cfg_print_cstr(pctx, " ) ");
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		cfg_print_cstr(pctx, "[ port ( <integer> | * ) ]");
 	} else {
 		cfg_print_cstr(pctx, "[ port <integer> ]");
@@ -3046,13 +3011,12 @@ parser_complain(cfg_parser_t *pctx, bool is_warning,
 		}
 
 		/* Choose a preposition. */
-		if ((flags & CFG_LOG_NEAR) != 0) {
+		if (flags & CFG_LOG_NEAR)
 			prep = " near ";
-		} else if ((flags & CFG_LOG_BEFORE) != 0) {
+		else if (flags & CFG_LOG_BEFORE)
 			prep = " before ";
-		} else {
+		else
 			prep = " ";
-		}
 	} else {
 		tokenbuf[0] = '\0';
 	}
